@@ -447,14 +447,16 @@ protected:
 	wxChar* m_pLine;
 };
 
-CDirectoryListingParser::CDirectoryListingParser(CControlSocket* pControlSocket, const CServer& server)
-	: m_pControlSocket(pControlSocket), m_server(server)
+CDirectoryListingParser::CDirectoryListingParser(CControlSocket* pControlSocket, const CServer& server, listingEncoding::type encoding)
+	: m_pControlSocket(pControlSocket)
+	, m_currentOffset(0)
+	, m_totalData()
+	, m_prevLine(0)
+	, m_server(server)
+	, m_fileListOnly(true)
+	, m_maybeMultilineVms(false)
+	, m_listingEncoding(encoding)
 {
-	m_currentOffset = 0;
-	m_prevLine = 0;
-	m_fileListOnly = true;
-	m_maybeMultilineVms = false;
-
 	if (m_MonthNamesMap.empty())
 	{
 		//Fill the month names map
@@ -514,7 +516,7 @@ CDirectoryListingParser::CDirectoryListingParser(CControlSocket* pControlSocket,
 
 		//French month names
 		m_MonthNamesMap[_T("janv")] = 1;
-		m_MonthNamesMap[_T("f\xe9")_T("b")] = 1;
+		m_MonthNamesMap[_T("f\xe9") _T("b")] = 1;
 		m_MonthNamesMap[_T("f\xe9v")] = 2;
 		m_MonthNamesMap[_T("fev")] = 2;
 		m_MonthNamesMap[_T("f\xe9vr")] = 2;
@@ -528,7 +530,7 @@ CDirectoryListingParser::CDirectoryListingParser(CControlSocket* pControlSocket,
 		m_MonthNamesMap[_T("ao\xfb")] = 8;
 		m_MonthNamesMap[_T("ao\xfbt")] = 8;
 		m_MonthNamesMap[_T("aout")] = 8;
-		m_MonthNamesMap[_T("d\xe9")_T("c")] = 12;
+		m_MonthNamesMap[_T("d\xe9") _T("c")] = 12;
 		m_MonthNamesMap[_T("dec")] = 12;
 
 		//Italian month names
@@ -628,6 +630,9 @@ CDirectoryListingParser::CDirectoryListingParser(CControlSocket* pControlSocket,
 		m_MonthNamesMap[_T("lap")] = 11;
 		m_MonthNamesMap[_T("grd")] = 12;
 
+		// Hungarian
+		m_MonthNamesMap[_T("szept")] = 9;
+
 		//There are more languages and thus month
 		//names, but as long as nobody reports a
 		//problem, I won't add them, there are way
@@ -688,6 +693,8 @@ CDirectoryListingParser::~CDirectoryListingParser()
 
 bool CDirectoryListingParser::ParseData(bool partial)
 {
+	DeduceEncoding();
+
 	bool error = false;
 	CLine *pLine = GetLine(partial, error);
 	while (pLine)
@@ -1193,7 +1200,7 @@ bool CDirectoryListingParser::ParseUnixDateTime(CLine *pLine, int &index, CDiren
 			int fileDayOfYear = (month - 1) * 31 + day;
 
 			// We have to compare with an offset of one. In the worst case,
-			// the server's timezone might be up to 24 hours ahead of the 
+			// the server's timezone might be up to 24 hours ahead of the
 			// client.
 			// Problem: Servers which do send the time but not the year even
 			// one day away from getting 1 year old. This is far more uncommon
@@ -1680,7 +1687,7 @@ bool CDirectoryListingParser::ParseAsVms(CLine *pLine, CDirentry &entry)
 	// Current token is either size or date
 	bool gotSize = false;
 	pos = token.Find('/');
-	
+
 	if (!pos)
 		return false;
 
@@ -1838,7 +1845,7 @@ bool CDirectoryListingParser::ParseAsIbm(CLine *pLine, CDirentry &entry)
 		entry.name.RemoveLast();
 		entry.flags |= CDirentry::flag_dir;
 	}
-	
+
 	if (entry.has_time())
 		entry.time.Add(m_timezoneOffset);
 
@@ -2025,11 +2032,17 @@ bool CDirectoryListingParser::ParseOther(CLine *pLine, CDirentry &entry)
 
 bool CDirectoryListingParser::AddData(char *pData, int len)
 {
+	ConvertEncoding( pData, len );
+
 	t_list item;
 	item.p = pData;
 	item.len = len;
 
 	m_DataList.push_back(item);
+	m_totalData += len;
+
+	if (m_totalData < 512)
+		return true;
 
 	return ParseData(true);
 }
@@ -2302,7 +2315,7 @@ bool CDirectoryListingParser::ParseAsIBM_MVS(CLine *pLine, CDirentry &entry)
 	// used
 	if (!pLine->GetToken(index++, token))
 		return false;
-	if (token.IsNumeric() || token.GetString() == _T("????"))
+	if (token.IsNumeric() || token.GetString() == _T("????") || token.GetString() == _T("++++") )
 	{
 		// recfm
 		if (!pLine->GetToken(index++, token))
@@ -2534,7 +2547,7 @@ bool CDirectoryListingParser::ParseAsIBM_MVS_Tape(CLine *pLine, CDirentry &entry
 	entry.ownerGroup = _T("");
 	entry.permissions = _T("");
 	entry.size = -1;
-	
+
 	if (pLine->GetToken(index++, token))
 		return false;
 
@@ -3006,8 +3019,99 @@ bool CDirectoryListingParser::GetMonthFromName(const wxString& name, int &month)
 		if (iter == m_MonthNamesMap.end())
 			return false;
 	}
-	
+
 	month = iter->second;
-	
+
 	return true;
 }
+
+char ebcdic_table[256] = {
+	' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  // 0
+	' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  '\n', // 1
+	' ',  ' ',  ' ',  ' ',  ' ',  '\n', ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  // 2
+	' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  // 3
+	' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  '.',  '<',  '(',  '+',  '|',  // 4
+	'&',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  '!',  '$',  '*',  ')',  ';',  ' ',  // 5
+	'-',  '/',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  '|',  ',',  '%',  '_',  '>',  '?',  // 6
+	' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  '`',  ':',  '#',  '@',  '\'', '=',  '"',  // 7
+	' ',  'a',  'b',  'c',  'd',  'e',  'f',  'g',  'h',  'i',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  // 8
+	' ',  'j',  'k',  'l',  'm',  'n',  'o',  'p',  'q',  'r',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  // 9
+	' ',  '~',  's',  't',  'u',  'v',  'w',  'x',  'y',  'z',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  // a
+	'^',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  '[',  ']',  ' ',  ' ',  ' ',  ' ',  // b
+	'{',  'A',  'B',  'C',  'D',  'E',  'F',  'G',  'H',  'I',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  // c
+	'}',  'J',  'K',  'L',  'M',  'N',  'O',  'P',  'Q',  'R',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  // d
+	'\\', ' ',  'S',  'T',  'U',  'V',  'W',  'X',  'Y',  'Z',  ' ',  ' ',  ' ',  ' ',  ' ',  ' ',  // e
+	'0',  '1',  '2',  '3',  '4',  '5',  '6',  '7',  '8',  '9',  ' ',  ' ',  ' ',  ' ',  ' ',  ' '   // f
+};
+
+void CDirectoryListingParser::ConvertEncoding(char *pData, int len)
+{
+	if (m_listingEncoding != listingEncoding::ebcdic)
+		return;
+
+	for (int i = 0; i < len; ++i)
+	{
+		pData[i] = ebcdic_table[static_cast<unsigned char>(pData[i])];
+	}
+}
+
+void CDirectoryListingParser::DeduceEncoding()
+{
+	if (m_listingEncoding != listingEncoding::unknown)
+		return;
+
+	int count[256];
+
+	memset(&count, 0, sizeof(int)*256);
+
+	for (std::list<t_list>::const_iterator it = m_DataList.begin(); it != m_DataList.end(); ++it)
+	{
+		for (int i = 0; i < it->len; ++i)
+			++count[static_cast<unsigned char>(it->p[i])];
+	}
+
+	int count_normal = 0;
+	int count_ebcdic = 0;
+	for (int i = '0'; i <= '9'; ++i ) {
+		count_normal += count[i];
+	}
+	for (int i = 'a'; i <= 'Z'; ++i ) {
+		count_normal += count[i];
+	}
+	for (int i = 'A'; i <= 'Z'; ++i ) {
+		count_normal += count[i];
+	}
+
+	for (int i = 0x81; i <= 0x89; ++i ) {
+		count_ebcdic += count[i];
+	}
+	for (int i = 0x91; i <= 0x99; ++i ) {
+		count_ebcdic += count[i];
+	}
+	for (int i = 0xa2; i <= 0xa9; ++i ) {
+		count_ebcdic += count[i];
+	}
+	for (int i = 0xc1; i <= 0x89; ++i ) {
+		count_ebcdic += count[i];
+	}
+	for (int i = 0xd1; i <= 0x99; ++i ) {
+		count_ebcdic += count[i];
+	}
+	for (int i = 0xe2; i <= 0xa9; ++i ) {
+		count_ebcdic += count[i];
+	}
+	for (int i = 0xf0; i <= 0xf9; ++i ) {
+		count_ebcdic += count[i];
+	}
+
+
+	if ((count[0x1f] || count[0x25]) && !count[0x0a] && count['@'] && count['@'] > count[' '] && count_ebcdic > count_normal)
+	{
+		m_pControlSocket->LogMessage(::Status, _("Received a directory listing which appears to be encoded in EBCDIC."));
+		m_listingEncoding = listingEncoding::ebcdic;
+		for (std::list<t_list>::iterator it = m_DataList.begin(); it != m_DataList.end(); ++it)
+			ConvertEncoding(it->p, it->len);
+	}
+	else
+		m_listingEncoding = listingEncoding::normal;
+}
