@@ -303,7 +303,7 @@ protected:
 		}
 loopexit:
 
-		return (ExitCode)Close();
+		return reinterpret_cast<ExitCode>(Close());
 	};
 
 	int Close()
@@ -328,7 +328,7 @@ public:
 		m_deleteFailed = false;
 	}
 
-	virtual ~CSftpDeleteOpData() { }
+	virtual ~CSftpDeleteOpData() {}
 
 	CServerPath path;
 	std::list<wxString> files;
@@ -399,6 +399,7 @@ int CSftpControlSocket::Connect(const CServer &server)
 	delete m_pCSConv;
 	if (server.GetEncodingType() == ENCODING_CUSTOM)
 	{
+		LogMessage(Debug_Info, _T("Using custom encoding: %s"), server.GetCustomEncoding().c_str());
 		m_pCSConv = new wxCSConv(server.GetCustomEncoding());
 		m_useUTF8 = false;
 	}
@@ -509,7 +510,7 @@ int CSftpControlSocket::ConnectParseResponse(bool successful, const wxString& re
 		return FZ_REPLY_OK;
 	default:
 		LogMessage(__TFILE__, __LINE__, this, Debug_Warning, _T("Unknown op state: %d"), pData->opState);
-        DoClose(FZ_REPLY_INTERNALERROR);
+		DoClose(FZ_REPLY_INTERNALERROR);
 		return FZ_REPLY_ERROR;
 	}
 
@@ -580,7 +581,7 @@ int CSftpControlSocket::ConnectSend()
 		break;
 	default:
 		LogMessage(__TFILE__, __LINE__, this, Debug_Warning, _T("Unknown op state: %d"), pData->opState);
-        DoClose(FZ_REPLY_INTERNALERROR);
+		DoClose(FZ_REPLY_INTERNALERROR);
 		return FZ_REPLY_ERROR;
 	}
 
@@ -1883,7 +1884,7 @@ int CSftpControlSocket::FileTransferSend()
 		}
 
 		wxString quotedFilename = QuoteFilename(pData->remotePath.FormatFilename(pData->remoteFile, !pData->tryAbsolutePath));
-		// Y2K38		
+		// Y2K38
 		time_t ticks = pData->fileTime.GetTicks(); // Already in UTC
 		wxString seconds = wxString::Format(_T("%d"), (int)ticks);
 		if (!Send(_T("chmtime ") + seconds + _T(" ") + WildcardEscape(quotedFilename),
@@ -2329,7 +2330,7 @@ public:
 	{
 	}
 
-	virtual ~CSftpRemoveDirOpData() { }
+	virtual ~CSftpRemoveDirOpData() {}
 
 	CServerPath path;
 	wxString subDir;
@@ -2411,7 +2412,7 @@ public:
 		m_useAbsolute = false;
 	}
 
-	virtual ~CSftpChmodOpData() { }
+	virtual ~CSftpChmodOpData() {}
 
 	CChmodCommand m_cmd;
 	bool m_useAbsolute;
@@ -2533,7 +2534,7 @@ public:
 		m_useAbsolute = false;
 	}
 
-	virtual ~CSftpRenameOpData() { }
+	virtual ~CSftpRenameOpData() {}
 
 	CRenameCommand m_cmd;
 	bool m_useAbsolute;
