@@ -53,7 +53,7 @@ union sockaddr_u
 // Apparently it is too hard for the richest company in the
 // world to add this simple function with a service pack...
 
-extern "C" 
+extern "C"
 {
 	typedef int (WINAPI *t_getaddrinfo)(const char *nodename, const char *servname,
 						const struct addrinfo *hints, struct addrinfo **res);
@@ -445,7 +445,7 @@ public:
 	{
 		if (!already_locked)
 			m_sync.Lock();
-			
+
 		if (!m_started || m_finished)
 		{
 			if (!already_locked)
@@ -503,7 +503,7 @@ protected:
 
 			return 0;
 		}
-		
+
 #if defined(SO_NOSIGPIPE) && !defined(MSG_NOSIGNAL)
 		// We do not want SIGPIPE if writing to socket.
 		const int value = 1;
@@ -759,7 +759,7 @@ protected:
 	{
 		m_waiting |= wait;
 
-		while (true)
+		for (;;)
 		{
 #ifdef __WXMSW__
 			int wait_events = FD_CLOSE;
@@ -859,7 +859,7 @@ protected:
 			int res = select(max, &readfds, &writefds, 0, 0);
 
 			m_sync.Lock();
-			
+
 			if (res > 0 && FD_ISSET(m_pipe[0], &readfds))
 			{
 				char buffer[100];
@@ -937,6 +937,8 @@ protected:
 			return;
 		if (m_triggered & WAIT_READ)
 		{
+			if (m_pSocket->m_synchronous_read_cb)
+				m_pSocket->m_synchronous_read_cb->cb();
 			CSocketEvent *evt = new CSocketEvent(m_pSocket->m_pEvtHandler, m_pSocket, CSocketEvent::read, m_triggered_errors[1]);
 			CSocketEventDispatcher::Get().SendEvent(evt);
 			m_triggered &= ~WAIT_READ;
@@ -981,7 +983,7 @@ protected:
 	virtual ExitCode Entry()
 	{
 		m_sync.Lock();
-		while (true)
+		for (;;)
 		{
 			if (!IdleLoop())
 			{
@@ -1077,10 +1079,13 @@ protected:
 
 	// Thread waits for instructions
 	bool m_threadwait;
+
+	CCallback* m_synchronous_read_cb;
 };
 
 CSocket::CSocket(CSocketEventHandler* pEvtHandler)
 	: m_pEvtHandler(pEvtHandler)
+	, m_synchronous_read_cb()
 {
 #ifdef ERRORCODETEST
 	CErrorCodeTest test;
@@ -1793,7 +1798,7 @@ int CSocket::GetLocalPort(int& error)
 
 int CSocket::GetRemotePort(int& error)
 {
-	sockaddr_u addr;		
+	sockaddr_u addr;
 	socklen_t addr_len = sizeof(addr);
 	error = getpeername(m_fd, &addr.sockaddr, &addr_len);
 	if (error)
@@ -1832,7 +1837,7 @@ CSocket* CSocket::Accept(int &error)
 #endif
 		return 0;
 	}
-	
+
 #if defined(SO_NOSIGPIPE) && !defined(MSG_NOSIGNAL)
 	// We do not want SIGPIPE if writing to socket.
 	const int value = 1;
@@ -1957,3 +1962,14 @@ int CSocket::DoSetBufferSizes(int fd, int size_read, int size_write)
 
 	return 0;
 }
+
+void CSocket::SetSynchronousReadCallback(CCallback* cb)
+{
+	if (m_pSocketThread)
+		m_pSocketThread->m_sync.Lock();
+
+	m_synchronous_read_cb = cb;
+
+	if (m_pSocketThread)
+		m_pSocketThread->m_sync.Unlock();
+}
