@@ -6,13 +6,20 @@
 #include <gnutls/x509.h>
 #include <errno.h>
 
+#if GNUTLS_VERSION_NUMBER >= 0x030100
+char const ciphers[] = "SECURE256:+SECURE128:+ARCFOUR-128:-3DES-CBC:-MD5:-SIGN-RSA-MD5:+CTYPE-X509:-CTYPE-OPENPGP";
+#else
+// Versions before 3.1.0 cannot combine level keywords
+char const ciphers[] = "SECURE128:+ARCFOUR-128:-3DES-CBC:-MD5:-SIGN-RSA-MD5:+CTYPE-X509:-CTYPE-OPENPGP";
+#endif
+
 //#define TLSDEBUG 1
 #if TLSDEBUG
 // This is quite ugly
 CControlSocket* pLoggingControlSocket;
 void log_func(int level, const char* msg)
 {
-	if (!msg)
+	if (!msg || !pLoggingControlSocket)
 		return;
 	wxString s(msg, wxConvLocal);
 	s.Trim();
@@ -71,36 +78,57 @@ bool CTlsSocket::Init()
 	int res = gnutls_global_init();
 	if (res)
 	{
-		LogError(res);
+		LogError(res, _T("gnutls_global_init"));
 		Uninit();
 		return false;
 	}
 
 #if TLSDEBUG
-	pLoggingControlSocket = m_pOwner;
-	gnutls_global_set_log_function(log_func);
-	gnutls_global_set_log_level(99);
+	if (!pLoggingControlSocket)
+	{
+		pLoggingControlSocket = m_pOwner;
+		gnutls_global_set_log_function(log_func);
+		gnutls_global_set_log_level(99);
+	}
 #endif
 	res = gnutls_certificate_allocate_credentials(&m_certCredentials);
 	if (res < 0)
 	{
-		LogError(res);
+		LogError(res, _T("gnutls_certificate_allocate_credentials"));
 		Uninit();
 		return false;
 	}
 
-	res = gnutls_init(&m_session, GNUTLS_CLIENT);
+	if (!InitSession())
+		return false;
+	
+	m_shutdown_requested = false;
+
+	// At this point, we can start shaking hands.
+
+	return true;
+}
+
+bool CTlsSocket::InitSession()
+{
+	int res = gnutls_init(&m_session, GNUTLS_CLIENT);
 	if (res)
 	{
-		LogError(res);
+		LogError(res, _T("gnutls_init"));
 		Uninit();
 		return false;
 	}
 
-	res = gnutls_priority_set_direct(m_session, "NORMAL:-3DES-CBC:-MD5:-SIGN-RSA-MD5:+CTYPE-X509:-CTYPE-OPENPGP", 0);
+	// Even though the name gnutls_db_set_cache_expiration
+	// implies expiration of some cache, it also governs
+	// the actual session lifetime, independend whether the
+	// session is cached or not.
+	gnutls_db_set_cache_expiration(m_session, 100000000);
+
+	res = gnutls_priority_set_direct(m_session, ciphers, 0);
 	if (res)
 	{
-		LogError(res);
+		LogError(res, _T("gnutls_priority_set_direct"));
 		Uninit();
 		return false;
 	}
@@ -117,20 +145,12 @@ bool CTlsSocket::Init()
 	gnutls_transport_set_lowat(m_session, 0);
 #endif
 
-	m_shutdown_requested = false;
-
-	// At this point, we can start shaking hands.
-
 	return true;
 }
 
 void CTlsSocket::Uninit()
 {
-	if (m_session)
-	{
-		gnutls_deinit(m_session);
-		m_session = 0;
-	}
+	UninitSession();
 
 	if (m_certCredentials)
 	{
@@ -154,9 +174,25 @@ void CTlsSocket::Uninit()
 	m_implicitTrustedCert.data = 0;
 
 	m_require_root_trust = false;
+
+#if TLSDEBUG
+	if (pLoggingControlSocket == m_pOwner)
+		pLoggingControlSocket = 0;
+#endif
 }
 
-void CTlsSocket::LogError(int code)
+
+void CTlsSocket::UninitSession()
+{
+	if (m_session)
+	{
+		gnutls_deinit(m_session);
+		m_session = 0;
+	}
+}
+
+
+void CTlsSocket::LogError(int code, const wxString& function)
 {
 	if (code == GNUTLS_E_WARNING_ALERT_RECEIVED || code == GNUTLS_E_FATAL_ALERT_RECEIVED)
 		PrintAlert();
@@ -170,10 +206,18 @@ void CTlsSocket::LogError(int code)
 #else
 		wxString str(error);
 #endif
-		m_pOwner->LogMessage(::Error, _T("GnuTLS error %d: %s"), code, str.c_str());
+		if (function.IsEmpty())
+			m_pOwner->LogMessage(::Error, _T("GnuTLS error %d: %s"), code, str.c_str());
+		else
+			m_pOwner->LogMessage(::Error, _T("GnuTLS error %d in %s: %s"), code, function.c_str(), str.c_str());
 	}
 	else
-		m_pOwner->LogMessage(::Error, _T("GnuTLS error %d"), code);
+	{
+		if (function.IsEmpty())
+			m_pOwner->LogMessage(::Error, _T("GnuTLS error %d"), code);
+		else
+			m_pOwner->LogMessage(::Error, _T("GnuTLS error %d in %s"), code, function.c_str());
+	}
 }
 
 void CTlsSocket::PrintAlert()
@@ -398,10 +442,10 @@ bool CTlsSocket::CopySessionData(const CTlsSocket* pPrimarySocket)
 
 	// Get buffer size
 	int res = gnutls_session_get_data(pPrimarySocket->m_session, 0, &session_data_size);
-	if (res)
+	if (res && res != GNUTLS_E_SHORT_MEMORY_BUFFER )
 	{
-		m_pOwner->LogMessage(Debug_Info, _T("gnutls_session_get_data on primary socket failed: %d"), res);
-		return false;
+		m_pOwner->LogMessage(Debug_Warning, _T("gnutls_session_get_data on primary socket failed: %d"), res);
+		return true;
 	}
 
 	// Get session data
@@ -410,20 +454,22 @@ bool CTlsSocket::CopySessionData(const CTlsSocket* pPrimarySocket)
 	if (res)
 	{
 		delete [] session_data;
-		m_pOwner->LogMessage(Debug_Info, _T("gnutls_session_get_data on primary socket failed: %d"), res);
-		return false;
+		m_pOwner->LogMessage(Debug_Warning, _T("gnutls_session_get_data on primary socket failed: %d"), res);
+		return true;
 	}
 
 	// Set session data
-	res = gnutls_session_set_data(m_session, session_data, session_data_size);
+	res = gnutls_session_set_data(m_session, session_data, session_data_size );
 	delete [] session_data;
 	if (res)
 	{
-		m_pOwner->LogMessage(Debug_Info, _T("gnutls_session_set_data failed: %d"), res);
-		return false;
+		m_pOwner->LogMessage(Debug_Info, _T("gnutls_session_set_data failed: %d. Going to reinitialize session."), res);
+		UninitSession();
+		if (!InitSession())
+			return false;
 	}
-
-	m_pOwner->LogMessage(Debug_Info, _T("Trying to resume existing TLS session."));
+	else
+		m_pOwner->LogMessage(Debug_Info, _T("Trying to resume existing TLS session."));
 
 	return true;
 }
@@ -447,13 +493,17 @@ int CTlsSocket::Handshake(const CTlsSocket* pPrimarySocket /*=0*/, bool try_resu
 		const gnutls_datum_t* const cert_list = gnutls_certificate_get_peers(pPrimarySocket->m_session, &cert_list_size);
 		if (cert_list && cert_list_size)
 		{
+			delete [] m_implicitTrustedCert.data;
 			m_implicitTrustedCert.data = new unsigned char[cert_list[0].size];
 			memcpy(m_implicitTrustedCert.data, cert_list[0].data, cert_list[0].size);
 			m_implicitTrustedCert.size = cert_list[0].size;
 		}
 
 		if (try_resume)
-			CopySessionData(pPrimarySocket);
+		{
+			if (!CopySessionData(pPrimarySocket))
+				return FZ_REPLY_ERROR;
+		}
 	}
 
 	return ContinueHandshake();
@@ -466,6 +516,13 @@ int CTlsSocket::ContinueHandshake()
 	wxASSERT(m_tlsState == handshake);
 
 	int res = gnutls_handshake(m_session);
+	while (res == GNUTLS_E_AGAIN || res == GNUTLS_E_INTERRUPTED)
+	{
+		if ( gnutls_record_get_direction(m_session) != 1 || !m_canWriteToSocket )
+			break;
+
+		res = gnutls_handshake(m_session);
+	}
 	if (!res)
 	{
 		m_pOwner->LogMessage(Debug_Info, _T("TLS Handshake successful"));
@@ -569,7 +626,7 @@ int CTlsSocket::Read(void *buffer, unsigned int len, int& error)
 	}
 	else
 	{
-		Failure(res, 0);
+		Failure(res, 0, _T("gnutls_record_recv"));
 		error = ECONNABORTED;
 	}
 
@@ -605,6 +662,10 @@ int CTlsSocket::Write(const void *buffer, unsigned int len, int& error)
 	buffer = (char*)buffer + m_writeSkip;
 
 	int res = gnutls_record_send(m_session, buffer, len);
+
+	while ((res == GNUTLS_E_INTERRUPTED || res == GNUTLS_E_AGAIN) && m_canWriteToSocket)
+		res = gnutls_record_send(m_session, 0, 0);
+
 	if (res >= 0)
 	{
 		error = 0;
@@ -633,7 +694,7 @@ int CTlsSocket::Write(const void *buffer, unsigned int len, int& error)
 	}
 	else
 	{
-		Failure(res, 0);
+		Failure(res, 0, _T("gnutls_record_send"));
 		error = ECONNABORTED;
 		return -1;
 	}
@@ -663,7 +724,10 @@ void CTlsSocket::CheckResumeFailedReadWrite()
 {
 	if (m_lastWriteFailed)
 	{
-		int res = gnutls_record_send(m_session, 0, 0);
+		int res = GNUTLS_E_AGAIN;
+		while ((res == GNUTLS_E_INTERRUPTED || res == GNUTLS_E_AGAIN) && m_canWriteToSocket)
+			res = gnutls_record_send(m_session, 0, 0);
+
 		if (res == GNUTLS_E_INTERRUPTED || res == GNUTLS_E_AGAIN)
 			return;
 
@@ -711,12 +775,12 @@ void CTlsSocket::CheckResumeFailedReadWrite()
 	}
 }
 
-void CTlsSocket::Failure(int code, int socket_error)
+void CTlsSocket::Failure(int code, int socket_error, const wxString& function)
 {
 	m_pOwner->LogMessage(::Debug_Debug, _T("CTlsSocket::Failure(%d, %d)"), code, socket_error);
 	if (code)
 	{
-		LogError(code);
+		LogError(code, function);
 		if (code == GNUTLS_E_UNEXPECTED_PACKET_LENGTH && m_socket_eof)
 			m_pOwner->LogMessage(Status, _("Server did not properly shut down TLS connection"));
 	}
@@ -775,6 +839,8 @@ int CTlsSocket::Shutdown()
 	m_tlsState = closing;
 
 	int res = gnutls_bye(m_session, GNUTLS_SHUT_WR);
+	while ((res == GNUTLS_E_INTERRUPTED || res == GNUTLS_E_AGAIN) && m_canWriteToSocket)
+		res = gnutls_bye(m_session, GNUTLS_SHUT_WR);
 	if (!res)
 	{
 		m_tlsState = closed;
@@ -793,6 +859,8 @@ void CTlsSocket::ContinueShutdown()
 	m_pOwner->LogMessage(Debug_Verbose, _T("CTlsSocket::ContinueShutdown()"));
 
 	int res = gnutls_bye(m_session, GNUTLS_SHUT_WR);
+	while ((res == GNUTLS_E_INTERRUPTED || res == GNUTLS_E_AGAIN) && m_canWriteToSocket)
+		res = gnutls_bye(m_session, GNUTLS_SHUT_WR);
 	if (!res)
 	{
 		m_tlsState = closed;
@@ -976,11 +1044,11 @@ int CTlsSocket::VerifyCertificate()
 				subject = wxString(dn, wxConvUTF8);
 			}
 			else
-				LogError(res);
+				LogError(res, _T("gnutls_x509_crt_get_dn"));
 			delete [] dn;
 		}
 		else
-			LogError(res);
+			LogError(res, _T("gnutls_x509_crt_get_dn"));
 		if (subject == _T(""))
 		{
 			m_pOwner->LogMessage(::Error, _("Could not get distinguished name of certificate subject, gnutls_x509_get_dn failed"));
@@ -1001,11 +1069,11 @@ int CTlsSocket::VerifyCertificate()
 				issuer = wxString(dn, wxConvUTF8);
 			}
 			else
-				LogError(res);
+				LogError(res, _T("gnutls_x509_crt_get_issuer_dn"));
 			delete [] dn;
 		}
 		else
-			LogError(res);
+			LogError(res, _T("gnutls_x509_crt_get_issuer_dn"));
 		if (issuer == _T(""))
 		{
 			m_pOwner->LogMessage(::Error, _("Could not get distinguished name of certificate issuer, gnutls_x509_get_issuer_dn failed"));
@@ -1098,3 +1166,52 @@ bool CTlsSocket::AddTrustedRootCertificate(const wxString& cert)
 
 	return gnutls_certificate_set_x509_trust_mem(m_certCredentials, &datum, GNUTLS_X509_FMT_PEM) > 0;
 }
+
+wxString CTlsSocket::ListTlsCiphers(wxString priority)
+{
+	if (priority.IsEmpty())
+		priority = wxString::FromUTF8(ciphers);
+
+	wxString list = wxString::Format(_T("Ciphers for %s:\n"), priority.c_str());
+
+#if GNUTLS_VERSION_NUMBER >= 0x030009
+    gnutls_priority_t pcache;
+    const char *err = 0;
+	int ret = gnutls_priority_init(&pcache, priority.mb_str(), &err);
+	if (ret < 0)
+	{
+		list += wxString::Format(_T("gnutls_priority_init failed with code %d: %s"), ret, wxString::FromUTF8(err ? err : "").c_str());
+		return list;
+	}
+	else
+	{
+		for (size_t i = 0; ; i++)
+		{
+			unsigned int idx;
+			ret = gnutls_priority_get_cipher_suite_index(pcache, i, &idx);
+			if (ret == GNUTLS_E_REQUESTED_DATA_NOT_AVAILABLE)
+				break;
+			if (ret == GNUTLS_E_UNKNOWN_CIPHER_SUITE)
+				continue;
+            
+			gnutls_protocol_t version;
+			unsigned char id[2];
+			const char* name = gnutls_cipher_suite_info(idx, id, NULL, NULL, NULL, &version);
+
+			if (name != 0)
+			{
+				list += wxString::Format(
+					_T("%-50s    0x%02x, 0x%02x    %s\n"),
+					wxString::FromUTF8(name).c_str(),
+					(unsigned char)id[0],
+					(unsigned char)id[1],
+					wxString::FromUTF8(gnutls_protocol_get_name(version)).c_str());
+			}
+		}
+	}
+#else
+	list += _T("Unknown\n");
+#endif
+
+	return list;
+}
