@@ -59,7 +59,7 @@ private:
 	~CSocketEventDispatcher();
 
 	virtual bool ProcessEvent(wxEvent& event);
-	
+
 	std::list<CSocketEvent*> m_pending_events;
 
 	wxCriticalSection m_sync;
@@ -84,6 +84,12 @@ public:
 	virtual ~CSocketEventSource();
 };
 
+class CCallback
+{
+public:
+	virtual void cb() {}
+};
+
 class CSocketThread;
 class CSocket : public CSocketEventSource
 {
@@ -116,8 +122,8 @@ public:
 		unspec, // AF_UNSPEC
 		ipv4,   // AF_INET
 		ipv6    // AF_INET6
-	};		
-		
+	};
+
 	// Connects to the given host, given as name, IPv4 or IPv6 address.
 	// Returns 0 on success, else an error code. Note: EINPROGRESS is
 	// not really an error. On success, you should still wait for the
@@ -172,6 +178,8 @@ public:
 	// accepted sockets
 	void SetBufferSizes(int size_read, int size_write);
 
+	void SetSynchronousReadCallback(CCallback* cb);
+
 protected:
 	static int DoSetFlags(int fd, int flags, int flags_mask);
 	static int DoSetBufferSizes(int fd, int size_read, int size_write);
@@ -194,6 +202,8 @@ protected:
 	int m_flags;
 
 	int m_buffer_sizes[2];
+
+	CCallback* m_synchronous_read_cb;
 };
 
 #ifdef __WXMSW__
