@@ -147,7 +147,7 @@ bool CheckForWin2003FirewallBug()
 	return true;
 }
 
-extern "C" 
+extern "C"
 {
 	typedef HRESULT (WINAPI *t_SetCurrentProcessExplicitAppUserModelID)(PCWSTR AppID);
 }
@@ -274,7 +274,7 @@ bool CFileZillaApp::OnInit()
 #ifndef _DEBUG
 	const wxString& buildType = CBuildInfo::GetBuildType();
 	if (buildType == _T("nightly"))
-        wxMessageBox(_T("You are using a nightly development version of FileZilla 3, do not expect anything to work.\r\nPlease use the official releases instead.\r\n\r\n\
+		wxMessageBox(_T("You are using a nightly development version of FileZilla 3, do not expect anything to work.\r\nPlease use the official releases instead.\r\n\r\n\
 Unless explicitly instructed otherwise,\r\n\
 DO NOT post bugreports,\r\n\
 DO NOT use it in production environments,\r\n\
@@ -444,7 +444,7 @@ wxString CFileZillaApp::GetDataDir(wxString fileToFind) const
 
 	// For each path, check for the resources
 	wxPathList::const_iterator node;
-	for (node = pathList.begin(); node != pathList.end(); node++)
+	for (node = pathList.begin(); node != pathList.end(); ++node)
 	{
 		wxString cur = *node;
 		if (FileExists(cur + fileToFind))
@@ -455,7 +455,7 @@ wxString CFileZillaApp::GetDataDir(wxString fileToFind) const
 			return cur + _T("/filezilla");
 	}
 
-	for (node = pathList.begin(); node != pathList.end(); node++)
+	for (node = pathList.begin(); node != pathList.end(); ++node)
 	{
 		wxString cur = *node;
 		if (FileExists(cur + _T("/..") + fileToFind))
@@ -464,7 +464,7 @@ wxString CFileZillaApp::GetDataDir(wxString fileToFind) const
 			return cur + _T("/../share/filezilla");
 	}
 
-	for (node = pathList.begin(); node != pathList.end(); node++)
+	for (node = pathList.begin(); node != pathList.end(); ++node)
 	{
 		wxString cur = *node;
 		if (FileExists(cur + _T("/../../") + fileToFind))
@@ -847,3 +847,46 @@ int CFileZillaApp::ProcessCommandLine()
 
 	return res;
 }
+
+#if USE_CHUNKED_PROCESS_PENDING_EVENTS
+void CFileZillaApp::ProcessPendingEvents()
+{
+	// Code copied from wxAppConsole::ProcessPendingEvents, adapted to
+	// process only 100 events in one go.
+#if wxUSE_THREADS
+	if ( !wxPendingEventsLocker )
+		return;
+#endif
+
+	// ensure that we're the only thread to modify the pending events list
+	wxENTER_CRIT_SECT( *wxPendingEventsLocker );
+
+	if ( !wxPendingEvents )
+	{
+		wxLEAVE_CRIT_SECT( *wxPendingEventsLocker );
+		return;
+	}
+
+	// iterate until the list becomes empty or 100 events have been
+	// processed, whichever comes first
+	wxList::compatibility_iterator node = wxPendingEvents->GetFirst();
+	int idleCounter = 100;
+	while (node)
+	{
+		wxEvtHandler *handler = (wxEvtHandler *)node->GetData();
+		wxPendingEvents->Erase(node);
+
+		// In ProcessPendingEvents(), new handlers might be add
+		// and we can safely leave the critical section here.
+		wxLEAVE_CRIT_SECT( *wxPendingEventsLocker );
+
+		handler->ProcessPendingEvents();
+
+		wxENTER_CRIT_SECT( *wxPendingEventsLocker );
+
+		node = --idleCounter ? wxPendingEvents->GetFirst() : 0;
+	}
+
+	wxLEAVE_CRIT_SECT( *wxPendingEventsLocker );
+}
+#endif
\ No newline at end of file
