@@ -105,7 +105,7 @@ public:
 				return wxDragNone;
 			}
 
-			if (!m_pLocalTreeView->m_pState->GetServer() || m_pRemoteDataObject->GetServer() != *m_pLocalTreeView->m_pState->GetServer())
+			if (!m_pLocalTreeView->m_pState->GetServer() || !m_pRemoteDataObject->GetServer().EqualsNoPass(*m_pLocalTreeView->m_pState->GetServer()))
 			{
 				wxMessageBox(_("Drag&drop between different servers has not been implemented yet."));
 				return wxDragNone;
@@ -556,7 +556,7 @@ wxString CLocalTreeView::HasSubdir(const wxString& dirname)
 	wxLogNull nullLog;
 
 	CFilterManager filter;
-	
+
 	CLocalFileSystem local_filesystem;
 	if (!local_filesystem.BeginFindFiles(dirname, true))
 		return _T("");
@@ -748,6 +748,7 @@ void CLocalTreeView::Refresh()
 		t_dir dir = dirsToCheck.front();
 		dirsToCheck.pop_front();
 
+		// Step 1: Check if directory exists
 		CLocalFileSystem local_filesystem;
 		if (!local_filesystem.BeginFindFiles(dir.dir, true))
 		{
@@ -767,9 +768,9 @@ void CLocalTreeView::Refresh()
 			continue;
 		}
 
+		// Step 2: Enumerate subdirectories on disk and sort them
 		std::list<wxString> dirs;
 
-		
 		wxString file;
 		const wxLongLong size(-1);
 		bool was_link;
@@ -789,21 +790,30 @@ void CLocalTreeView::Refresh()
 
 			dirs.push_back(file);
 		}
-		dirs.sort(sortfunc);		
+		dirs.sort(sortfunc);
 
 		bool inserted = false;
 
+		// Step 3: Merge list of subdirectories with subtree.
 		wxTreeItemId child = GetLastChild(dir.item);
 		std::list<wxString>::reverse_iterator iter = dirs.rbegin();
-		while (child && iter != dirs.rend())
+		while (child || iter != dirs.rend())
 		{
+			int cmp;
+			if (child && iter != dirs.rend())
 #ifdef __WXMSW__
-			int cmp = GetItemText(child).CmpNoCase(*iter);
+				cmp = GetItemText(child).CmpNoCase(*iter);
 #else
-			int cmp = GetItemText(child).Cmp(*iter);
+				cmp = GetItemText(child).Cmp(*iter);
 #endif
+			else if (child)
+				cmp = 1;
+			else
+				cmp = -1;
+
 			if (!cmp)
 			{
+				// Found item with same name. Mark it for further processing
 				if (!IsExpanded(child))
 				{
 					wxString path = dir.dir + *iter + separator;
@@ -823,10 +833,13 @@ void CLocalTreeView::Refresh()
 					dirsToCheck.push_front(subdir);
 				}
 				child = GetPrevSibling(child);
-				iter++;
+				++iter;
 			}
 			else if (cmp > 0)
 			{
+				// Subdirectory currently in tree no longer exists.
+				// Delete child from tree, unless current selection
+				// is in the subtree.
 				wxTreeItemId sel = GetSelection();
 				while (sel && sel != child)
 					sel = GetItemParent(sel);
@@ -837,6 +850,7 @@ void CLocalTreeView::Refresh()
 			}
 			else if (cmp < 0)
 			{
+				// New subdirectory, add treeitem
 				wxString fullname = dir.dir + *iter + separator;
 				wxTreeItemId newItem = AppendItem(dir.item, *iter, GetIconIndex(::dir, fullname),
 #ifdef __WXMSW__
@@ -847,35 +861,10 @@ void CLocalTreeView::Refresh()
 					);
 
 				CheckSubdirStatus(newItem, fullname);
-				iter++;
+				++iter;
 				inserted = true;
 			}
 		}
-		while (child)
-		{
-			wxTreeItemId sel = GetSelection();
-			while (sel && sel != child)
-				sel = GetItemParent(sel);
-			wxTreeItemId prev = GetPrevSibling(child);
-			if (!sel)
-				Delete(child);
-			child = prev;
-		}
-		while (iter != dirs.rend())
-		{
-			wxString fullname = dir.dir + *iter + separator;
-			wxTreeItemId newItem = AppendItem(dir.item, *iter, GetIconIndex(::dir, fullname),
-#ifdef __WXMSW__
-					-1
-#else
-					GetIconIndex(opened_dir, fullname)
-#endif
-				);
-
-			CheckSubdirStatus(newItem, fullname);
-			iter++;
-			inserted = true;
-		}
 		if (inserted)
 			SortChildren(dir.item);
 	}
@@ -1026,7 +1015,7 @@ wxString CLocalTreeView::GetSpecialFolder(int folder, int &iconIndex, int &openI
 	wxString name = shFinfo.szDisplayName;
 
 	LPMALLOC pMalloc;
-    SHGetMalloc(&pMalloc);
+	SHGetMalloc(&pMalloc);
 
 	if (pMalloc)
 	{
@@ -1091,7 +1080,7 @@ void CLocalTreeView::OnVolumesEnumerated(wxCommandEvent& event)
 		m_pVolumeEnumeratorThread = 0;
 	}
 
-	for (std::list<CVolumeDescriptionEnumeratorThread::t_VolumeInfo>::const_iterator iter = volumeInfo.begin(); iter != volumeInfo.end(); iter++)
+	for (std::list<CVolumeDescriptionEnumeratorThread::t_VolumeInfo>::const_iterator iter = volumeInfo.begin(); iter != volumeInfo.end(); ++iter)
 	{
 		wxString drive = iter->volume;
 
