@@ -336,7 +336,7 @@ CMainFrame::CMainFrame()
 	m_pContextControl->CreateTab();
 
 	m_pContextControl->GetCurrentControls();
-	
+
 	switch (message_log_position)
 	{
 	case 1:
@@ -508,7 +508,7 @@ bool CMainFrame::CreateMenus()
 		delete m_pMenuBar;
 	}
 	m_pMenuBar = CMenuBar::Load(this);
-	
+
 	if (!m_pMenuBar)
 		return false;
 
@@ -623,6 +623,14 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 		int *x = 0;
 		*x = 0;
 	}
+	else if (event.GetId() == XRCID("ID_CIPHERS"))
+	{
+		CInputDialog dlg;
+		dlg.Create(this, _T("Ciphers"), _T("Priority string:"));
+		dlg.AllowEmpty(true);
+		if (dlg.ShowModal() == wxID_OK)
+			wxMessageBox(ListTlsCiphers(dlg.GetValue()), _T("Ciphers"));
+	}
 	else if (event.GetId() == XRCID("ID_CLEARCACHE_LAYOUT"))
 	{
 		CWrapEngine::ClearCache();
@@ -674,7 +682,7 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 
 		COptions::Get()->SetOption(OPTION_VIEW_HIDDEN_FILES, showHidden ? 1 : 0);
 		const std::vector<CState*> *pStates = CContextManager::Get()->GetAllStates();
-		for (std::vector<CState*>::const_iterator iter = pStates->begin(); iter != pStates->end(); iter++)
+		for (std::vector<CState*>::const_iterator iter = pStates->begin(); iter != pStates->end(); ++iter)
 		{
 			CState* pState = *iter;
 			CServerPath path = pState->GetRemotePath();
@@ -854,7 +862,7 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 			CSiteManager::GetBookmarks(controls->site_bookmarks->path, controls->site_bookmarks->bookmarks);
 			if (m_pMenuBar)
 				m_pMenuBar->UpdateBookmarkMenu();
-		}	
+		}
 	}
 	else if (event.GetId() == XRCID("ID_MENU_HELP_WELCOME"))
 	{
@@ -942,11 +950,11 @@ void CMainFrame::OnEngineEvent(wxEvent &event)
 
 	const std::vector<CState*> *pStates = CContextManager::Get()->GetAllStates();
 	CState* pState = 0;
-	for (std::vector<CState*>::const_iterator iter = pStates->begin(); iter != pStates->end(); iter++)
+	for (std::vector<CState*>::const_iterator iter = pStates->begin(); iter != pStates->end(); ++iter)
 	{
 		if ((*iter)->m_pEngine != pEngine)
 			continue;
-		
+
 		pState = *iter;
 		break;
 	}
@@ -1118,6 +1126,79 @@ BOOL CALLBACK FzEnumThreadWndProc(HWND hwnd, LPARAM lParam)
 }
 #endif //__WXMSW__
 
+
+bool CMainFrame::CloseDialogsAndQuit(wxCloseEvent &event)
+{
+#ifndef __WXMAC__
+	if (m_taskBarIcon)
+	{
+		delete m_taskBarIcon;
+		m_taskBarIcon = 0;
+		m_closeEvent = event.GetEventType();
+		m_closeEventTimer.Start(1, true);
+		return false;
+	}
+#endif
+
+	// We need to close all other top level windows on the stack before closing the main frame.
+	// In other words, all open dialogs need to be closed.
+	static int prev_size = 0;
+
+	int size = wxTopLevelWindows.size();
+	static wxTopLevelWindow* pLast = 0;
+	if (wxTopLevelWindows.size())
+	{
+		wxWindowList::reverse_iterator iter = wxTopLevelWindows.rbegin();
+		wxTopLevelWindow* pTop = (wxTopLevelWindow*)(*iter);
+		while (pTop != this && (size != prev_size || pLast != pTop))
+		{
+			wxDialog* pDialog = wxDynamicCast(pTop, wxDialog);
+			if (pDialog)
+				pDialog->EndModal(wxID_CANCEL);
+			else
+			{
+				wxWindow* pParent = pTop->GetParent();
+				if (m_pQueuePane && pParent == m_pQueuePane)
+				{
+					// It's the AUI frame manager hint window. Ignore it
+					++iter;
+					if (iter == wxTopLevelWindows.rend())
+						break;
+					pTop = (wxTopLevelWindow*)(*iter);
+					continue;
+				}
+				wxString title = pTop->GetTitle();
+				pTop->Destroy();
+			}
+
+			prev_size = size;
+			pLast = pTop;
+
+			m_closeEvent = event.GetEventType();
+			m_closeEventTimer.Start(1, true);
+
+			return false;
+		}
+	}
+
+#ifdef __WXMSW__
+	// wxMessageBox does not use wxTopLevelWindow, close it too
+	bool dialog = false;
+	EnumThreadWindows(GetCurrentThreadId(), FzEnumThreadWndProc, (LPARAM)&dialog);
+	if (dialog)
+	{
+		m_closeEvent = event.GetEventType();
+		m_closeEventTimer.Start(1, true);
+
+		return false;
+	}
+#endif //__WXMSW__
+
+	// At this point all other top level windows should be closed.
+	return true;
+}
+
+
 void CMainFrame::OnClose(wxCloseEvent &event)
 {
 	if (!m_bQuit)
@@ -1177,60 +1258,6 @@ void CMainFrame::OnClose(wxCloseEvent &event)
 			quit_confirmation_displayed = false;
 		}
 
-		if (!event.CanVeto())
-		{
-			// We need to close all other top level windows on the stack before closing the main frame.
-			// In other words, all open dialogs need to be closed.
-			static int prev_size = 0;
-
-			int size = wxTopLevelWindows.size();
-			static wxTopLevelWindow* pLast = 0;
-			wxWindowList::reverse_iterator iter = wxTopLevelWindows.rbegin();
-			wxTopLevelWindow* pTop = (wxTopLevelWindow*)(*iter);
-			while (pTop != this && (size != prev_size || pLast != pTop))
-			{
-				wxDialog* pDialog = wxDynamicCast(pTop, wxDialog);
-				if (pDialog)
-					pDialog->EndModal(wxID_CANCEL);
-				else
-				{
-					wxWindow* pParent = pTop->GetParent();
-					if (m_pQueuePane && pParent == m_pQueuePane)
-					{
-						// It's the AUI frame manager hint window. Ignore it
-						iter++;
-						pTop = (wxTopLevelWindow*)(*iter);
-						continue;
-					}
-					wxString title = pTop->GetTitle();
-					pTop->Destroy();
-				}
-
-				prev_size = size;
-				pLast = pTop;
-
-				m_closeEvent = event.GetEventType();
-				m_closeEventTimer.Start(1, true);
-
-				return;
-			}
-
-#ifdef __WXMSW__
-			// wxMessageBox does not use wxTopLevelWindow, close it too
-			bool dialog = false;
-			EnumThreadWindows(GetCurrentThreadId(), FzEnumThreadWndProc, (LPARAM)&dialog);
-			if (dialog)
-			{
-				m_closeEvent = event.GetEventType();
-				m_closeEventTimer.Start(1, true);
-
-				return;
-			}
-#endif //__WXMSW__
-
-			// At this point all other top level windows should be closed.
-		}
-
 		if (m_pWindowStateManager)
 		{
 			m_pWindowStateManager->Remember(OPTION_MAINWINDOW_POSITION);
@@ -1239,7 +1266,7 @@ void CMainFrame::OnClose(wxCloseEvent &event)
 		}
 
 		RememberSplitterPositions();
-		
+
 #ifdef __WXMAC__
 		if (m_pToolBar)
 			COptions::Get()->SetOption(OPTION_TOOLBAR_HIDDEN, m_pToolBar->IsShown() ? 0 : 1);
@@ -1248,6 +1275,8 @@ void CMainFrame::OnClose(wxCloseEvent &event)
 	}
 
 	Show(false);
+	if (!CloseDialogsAndQuit(event))
+		return;
 
 	// Getting deleted by wxWidgets
 	for (int i = 0; i < 2; i++)
@@ -1277,7 +1306,7 @@ void CMainFrame::OnClose(wxCloseEvent &event)
 
 	bool res = true;
 	const std::vector<CState*> *pStates = CContextManager::Get()->GetAllStates();
-	for (std::vector<CState*>::const_iterator iter = pStates->begin(); iter != pStates->end(); iter++)
+	for (std::vector<CState*>::const_iterator iter = pStates->begin(); iter != pStates->end(); ++iter)
 	{
 		CState* pState = *iter;
 		if (!pState->m_pCommandQueue)
@@ -1301,7 +1330,7 @@ void CMainFrame::OnClose(wxCloseEvent &event)
 		COptions::Get()->SetOption(OPTION_LAST_CONNECTED_SITE, controls->site_bookmarks->path);
 	}
 
-	for (std::vector<CState*>::const_iterator iter = pStates->begin(); iter != pStates->end(); iter++)
+	for (std::vector<CState*>::const_iterator iter = pStates->begin(); iter != pStates->end(); ++iter)
 	{
 		CState *pState = *iter;
 		pState->DestroyEngine();
@@ -1581,7 +1610,7 @@ void CMainFrame::OnToggleLogView(wxCommandEvent& event)
 			shown = true;
 		}
 	}
-	
+
 	if (COptions::Get()->GetOptionVal(OPTION_MESSAGELOG_POSITION) != 2)
 		COptions::Get()->SetOption(OPTION_SHOW_MESSAGELOG, shown);
 }
@@ -1632,7 +1661,7 @@ void CMainFrame::ShowLocalTree()
 			continue;
 
 		controls->pLocalTreeViewPanel->SetHeader(controls->pLocalListViewPanel->DetachHeader());
-		
+
 		if (layout == 3 && swap)
 			controls->pLocalSplitter->SplitVertically(controls->pLocalListViewPanel, controls->pLocalTreeViewPanel);
 		else if (layout)
@@ -1796,12 +1825,12 @@ void CMainFrame::UpdateLayout(int layout /*=-1*/, int swap /*=-1*/, int messagel
 
 	if (messagelog_position == -1)
 		messagelog_position = COptions::Get()->GetOptionVal(OPTION_MESSAGELOG_POSITION);
-	
+
 	// First handle changes in message log position as it can make size of the other panes change
 	{
 		bool shown = m_pStatusView->IsShown();
 		wxWindow* parent = m_pStatusView->GetParent();
-	
+
 		bool changed;
 		if (parent == m_pTopSplitter && messagelog_position != 0)
 		{
@@ -1987,7 +2016,7 @@ void CMainFrame::OnSitemanagerDropdown(wxCommandEvent& event)
 	ShowDropdownMenu(pMenu, m_pToolBar, event);
 }
 
-bool CMainFrame::ConnectToSite(CSiteManagerItemData_Site* const pData)
+bool CMainFrame::ConnectToSite(CSiteManagerItemData_Site* const pData, bool newTab)
 {
 	wxASSERT(pData);
 
@@ -1998,6 +2027,9 @@ bool CMainFrame::ConnectToSite(CSiteManagerItemData_Site* const pData)
 			return false;
 	}
 
+	if (newTab)
+		m_pContextControl->CreateTab();
+
 	if (!ConnectToServer(pData->m_server, pData->m_remoteDir))
 		return false;
 
@@ -2094,7 +2126,7 @@ void CMainFrame::OnNavigationKeyEvent(wxNavigationKeyEvent& event)
 	windowOrder.push_back(m_pQueuePane);
 
 	std::list<wxWindow*>::iterator iter;
-	for (iter = windowOrder.begin(); iter != windowOrder.end(); iter++)
+	for (iter = windowOrder.begin(); iter != windowOrder.end(); ++iter)
 	{
 		if (*iter == event.GetEventObject())
 			break;
@@ -2150,7 +2182,7 @@ void CMainFrame::OnChar(wxKeyEvent& event)
 	else
 	{
 		wxWindow *parent = focused->GetParent();
-		for (iter = windowOrder.begin(); iter != windowOrder.end(); iter++)
+		for (iter = windowOrder.begin(); iter != windowOrder.end(); ++iter)
 		{
 			if (*iter == focused || *iter == parent)
 			{
@@ -2177,7 +2209,7 @@ void CMainFrame::FocusNextEnabled(std::list<wxWindow*>& windowOrder, std::list<w
 		skipFirst = false;
 		if (forward)
 		{
-			iter++;
+			++iter;
 			if (iter == windowOrder.end())
 				iter = windowOrder.begin();
 		}
@@ -2185,7 +2217,7 @@ void CMainFrame::FocusNextEnabled(std::list<wxWindow*>& windowOrder, std::list<w
 		{
 			if (iter == windowOrder.begin())
 				iter = windowOrder.end();
-			iter--;
+			--iter;
 		}
 
 		if (iter == start)
@@ -2203,7 +2235,7 @@ void CMainFrame::RememberSplitterPositions()
 	CContextControl::_context_controls* controls = m_pContextControl->GetCurrentControls();
 	if (!controls)
 		return;
-	
+
 	wxString posString;
 
 	// top_pos
@@ -2398,7 +2430,7 @@ void CMainFrame::ShowDropdownMenu(wxMenu* pMenu, wxToolBar* pToolBar, wxCommandE
 	{
 #ifdef __WXMSW__
 		RECT r;
-        if (::SendMessage((HWND)pToolBar->GetHandle(), TB_GETITEMRECT, pToolBar->GetToolPos(event.GetId()), (LPARAM)&r))
+		if (::SendMessage((HWND)pToolBar->GetHandle(), TB_GETITEMRECT, pToolBar->GetToolPos(event.GetId()), (LPARAM)&r))
 			pToolBar->PopupMenu(pMenu, r.left, r.bottom);
 		else
 #endif
@@ -2460,7 +2492,7 @@ void CMainFrame::ProcessCommandLine()
 
 		if (pData)
 		{
-            if (ConnectToSite(pData))
+			if (ConnectToSite(pData))
 			{
 				SetBookmarksFromPath(site);
 				if (m_pMenuBar)
@@ -2549,7 +2581,7 @@ WXLRESULT CMainFrame::MSWWindowProc(WXUINT nMsg, WXWPARAM wParam, WXLPARAM lPara
 		// create another instance of the module and call its Exit() member.
 		// After that, the next call to a wxDisplay will create a new factory and
 		// get the new display layout from Windows.
-		// 
+		//
 		// Note: Both the factory pattern as well as the dynamic object system
 		//       are perfect example of bad design.
 		//
