@@ -55,14 +55,15 @@ public:
 	void ProcessCommandLine();
 
 	void PostInitialize();
-	
+
 	bool ConnectToServer(const CServer& server, const CServerPath& path = CServerPath());
 
 	CContextControl* GetContextControl() { return m_pContextControl; }
 
-	bool ConnectToSite(CSiteManagerItemData_Site* const pData);
+	bool ConnectToSite(CSiteManagerItemData_Site* const pData, bool newTab = false);
 
 protected:
+	bool CloseDialogsAndQuit(wxCloseEvent &event);
 	bool CreateMenus();
 	bool CreateQuickconnectBar();
 	bool CreateToolBar();
@@ -117,6 +118,7 @@ protected:
 	void OnSiteManager(wxCommandEvent& event);
 	void OnProcessQueue(wxCommandEvent& event);
 	void OnMenuEditSettings(wxCommandEvent& event);
+	void OnToggleToolBar(wxCommandEvent& event);
 	void OnToggleLogView(wxCommandEvent& event);
 	void OnToggleLocalTreeView(wxCommandEvent& event);
 	void OnToggleRemoteTreeView(wxCommandEvent& event);
@@ -171,6 +173,8 @@ protected:
 	// While set, ignore iconize events.
 	bool m_taskbar_is_uniconizing;
 #endif
+
+	int m_comparisonToggleAcceleratorId;
 };
 
 #endif
