@@ -204,7 +204,9 @@ void CEditHandler::Release()
 		if (m_lockfile_descriptor >= 0)
 			close(m_lockfile_descriptor);
 #endif
-
+		
+		wxRemoveFile(m_localDir + _T("empty_file_yq744zm"));
+		
 		RemoveAll(true);
 		wxRmdir(m_localDir);
 	}
@@ -246,7 +248,7 @@ int CEditHandler::GetFileCount(enum CEditHandler::fileType type, enum CEditHandl
 	{
 		if (type != remote)
 		{
-			for (std::list<t_fileData>::const_iterator iter = m_fileDataList[local].begin(); iter != m_fileDataList[local].end(); iter++)
+			for (std::list<t_fileData>::const_iterator iter = m_fileDataList[local].begin(); iter != m_fileDataList[local].end(); ++iter)
 			{
 				if (iter->state != state)
 					continue;
@@ -257,7 +259,7 @@ int CEditHandler::GetFileCount(enum CEditHandler::fileType type, enum CEditHandl
 		}
 		if (type != local)
 		{
-			for (std::list<t_fileData>::const_iterator iter = m_fileDataList[remote].begin(); iter != m_fileDataList[remote].end(); iter++)
+			for (std::list<t_fileData>::const_iterator iter = m_fileDataList[remote].begin(); iter != m_fileDataList[remote].end(); ++iter)
 			{
 				if (iter->state != state)
 					continue;
@@ -355,7 +357,7 @@ bool CEditHandler::RemoveAll(bool force)
 {
 	std::list<t_fileData> keep;
 
-	for (std::list<t_fileData>::iterator iter = m_fileDataList[remote].begin(); iter != m_fileDataList[remote].end(); iter++)
+	for (std::list<t_fileData>::iterator iter = m_fileDataList[remote].begin(); iter != m_fileDataList[remote].end(); ++iter)
 	{
 		if (!force && (iter->state == download || iter->state == upload || iter->state == upload_and_remove))
 		{
@@ -376,7 +378,7 @@ bool CEditHandler::RemoveAll(bool force)
 	m_fileDataList[remote].swap(keep);
 	keep.clear();
 
-	for (std::list<t_fileData>::iterator iter = m_fileDataList[local].begin(); iter != m_fileDataList[local].end(); iter++)
+	for (std::list<t_fileData>::iterator iter = m_fileDataList[local].begin(); iter != m_fileDataList[local].end(); ++iter)
 	{
 		if (force)
 			continue;
@@ -401,7 +403,7 @@ bool CEditHandler::RemoveAll(enum fileState state, const CServer* pServer /*=0*/
 
 	std::list<t_fileData> keep;
 
-	for (std::list<t_fileData>::iterator iter = m_fileDataList[remote].begin(); iter != m_fileDataList[remote].end(); iter++)
+	for (std::list<t_fileData>::iterator iter = m_fileDataList[remote].begin(); iter != m_fileDataList[remote].end(); ++iter)
 	{
 		if (iter->state != state)
 		{
@@ -433,7 +435,7 @@ bool CEditHandler::RemoveAll(enum fileState state, const CServer* pServer /*=0*/
 std::list<CEditHandler::t_fileData>::iterator CEditHandler::GetFile(const wxString& fileName)
 {
 	std::list<t_fileData>::iterator iter;
-	for (iter = m_fileDataList[local].begin(); iter != m_fileDataList[local].end(); iter++)
+	for (iter = m_fileDataList[local].begin(); iter != m_fileDataList[local].end(); ++iter)
 	{
 		if (iter->file == fileName)
 			break;
@@ -445,7 +447,7 @@ std::list<CEditHandler::t_fileData>::iterator CEditHandler::GetFile(const wxStri
 std::list<CEditHandler::t_fileData>::const_iterator CEditHandler::GetFile(const wxString& fileName) const
 {
 	std::list<t_fileData>::const_iterator iter;
-	for (iter = m_fileDataList[local].begin(); iter != m_fileDataList[local].end(); iter++)
+	for (iter = m_fileDataList[local].begin(); iter != m_fileDataList[local].end(); ++iter)
 	{
 		if (iter->file == fileName)
 			break;
@@ -457,7 +459,7 @@ std::list<CEditHandler::t_fileData>::const_iterator CEditHandler::GetFile(const
 std::list<CEditHandler::t_fileData>::iterator CEditHandler::GetFile(const wxString& fileName, const CServerPath& remotePath, const CServer& server)
 {
 	std::list<t_fileData>::iterator iter;
-	for (iter = m_fileDataList[remote].begin(); iter != m_fileDataList[remote].end(); iter++)
+	for (iter = m_fileDataList[remote].begin(); iter != m_fileDataList[remote].end(); ++iter)
 	{
 		if (iter->name != fileName)
 			continue;
@@ -477,7 +479,7 @@ std::list<CEditHandler::t_fileData>::iterator CEditHandler::GetFile(const wxStri
 std::list<CEditHandler::t_fileData>::const_iterator CEditHandler::GetFile(const wxString& fileName, const CServerPath& remotePath, const CServer& server) const
 {
 	std::list<t_fileData>::const_iterator iter;
-	for (iter = m_fileDataList[remote].begin(); iter != m_fileDataList[remote].end(); iter++)
+	for (iter = m_fileDataList[remote].begin(); iter != m_fileDataList[remote].end(); ++iter)
 	{
 		if (iter->name != fileName)
 			continue;
@@ -629,7 +631,7 @@ void CEditHandler::CheckForModifications(bool emitEvent)
 	for (int i = 0; i < 2; i++)
 	{
 checkmodifications_loopbegin:
-		for (std::list<t_fileData>::iterator iter = m_fileDataList[i].begin(); iter != m_fileDataList[i].end(); iter++)
+		for (std::list<t_fileData>::iterator iter = m_fileDataList[i].begin(); iter != m_fileDataList[i].end(); ++iter)
 		{
 			if (iter->state != edit)
 				continue;
@@ -740,7 +742,7 @@ int CEditHandler::DisplayChangeNotification(CEditHandler::fileType type, std::li
 		int pos = file.Find(wxFileName::GetPathSeparator(), true);
 		wxASSERT(pos != -1);
 		file = file.Mid(pos + 1);
-	
+
 		if (file == iter->name)
 		{
 			XRCCTRL(dlg, "ID_DESC_OPENEDAS", wxStaticText)->Hide();
@@ -963,7 +965,7 @@ wxString CEditHandler::GetSystemOpenCommand(wxString file, bool &program_exists)
 	if (ext == _T(""))
 		return _T("");
 
-	while (true)
+	for (;;)
 	{
 		wxFileType* pType = wxTheMimeTypesManager->GetFileTypeFromExtension(ext);
 		if (!pType)
@@ -1071,7 +1073,7 @@ wxString CEditHandler::GetCustomOpenCommand(const wxString& file, bool& program_
 			program_exists = false;
 			return prog;
 		}
-		
+
 		program_exists = true;
 		return command + _T(" \"") + fn.GetFullPath() + _T("\"");
 	}
@@ -1152,13 +1154,13 @@ wxString CEditHandler::TruncateFilename(const wxString path, const wxString& nam
 			return name.Left(max - pathlen - extlen) + name.Mid(pos);
 		}
 	}
-	
+
 	return name;
 }
 
 bool CEditHandler::FilenameExists(const wxString& file)
 {
-	for (std::list<t_fileData>::const_iterator iter = m_fileDataList[remote].begin(); iter != m_fileDataList[remote].end(); iter++)
+	for (std::list<t_fileData>::const_iterator iter = m_fileDataList[remote].begin(); iter != m_fileDataList[remote].end(); ++iter)
 	{
 #ifdef __WXMSW__
 		if (!iter->file.CmpNoCase(file))
@@ -1235,7 +1237,7 @@ int CEditHandlerStatusDialog::ShowModal()
 	{
 		const std::list<CEditHandler::t_fileData>& files = pEditHandler->GetFiles(CEditHandler::remote);
 		unsigned int i = 0;
-		for (std::list<CEditHandler::t_fileData>::const_iterator iter = files.begin(); iter != files.end(); iter++, i++)
+		for (std::list<CEditHandler::t_fileData>::const_iterator iter = files.begin(); iter != files.end(); ++iter, ++i)
 		{
 			pListCtrl->InsertItem(i, iter->name);
 			pListCtrl->SetItem(i, COLUMN_TYPE, _("Remote"));
@@ -1272,7 +1274,7 @@ int CEditHandlerStatusDialog::ShowModal()
 	{
 		const std::list<CEditHandler::t_fileData>& files = pEditHandler->GetFiles(CEditHandler::local);
 		unsigned int i = 0;
-		for (std::list<CEditHandler::t_fileData>::const_iterator iter = files.begin(); iter != files.end(); iter++, i++)
+		for (std::list<CEditHandler::t_fileData>::const_iterator iter = files.begin(); iter != files.end(); ++iter, ++i)
 		{
 			pListCtrl->InsertItem(i, iter->file);
 			pListCtrl->SetItem(i, COLUMN_TYPE, _("Local"));
@@ -1376,13 +1378,13 @@ void CEditHandlerStatusDialog::OnUnedit(wxCommandEvent& event)
 		files.push_front(item);
 	}
 
-	for (std::list<int>::const_iterator iter = files.begin(); iter != files.end(); iter++)
+	for (std::list<int>::const_iterator iter = files.begin(); iter != files.end(); ++iter)
 	{
 		const int i = *iter;
 
 		enum CEditHandler::fileType type;
 		CEditHandler::t_fileData* pData = GetDataFromItem(i, type);
-		
+
 		if (type == CEditHandler::local)
 		{
 			pEditHandler->Remove(pData->file);
@@ -1429,7 +1431,7 @@ void CEditHandlerStatusDialog::OnUpload(wxCommandEvent& event)
 		files.push_front(item);
 	}
 
-	for (std::list<int>::const_iterator iter = files.begin(); iter != files.end(); iter++)
+	for (std::list<int>::const_iterator iter = files.begin(); iter != files.end(); ++iter)
 	{
 		const int i = *iter;
 
@@ -1467,7 +1469,7 @@ void CEditHandlerStatusDialog::OnEdit(wxCommandEvent& event)
 	while ((item = pListCtrl->GetNextItem(item, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED)) != -1)
 	{
 		pListCtrl->SetItemState(item, 0, wxLIST_STATE_SELECTED);
-		
+
 		enum CEditHandler::fileType type;
 		CEditHandler::t_fileData* pData = GetDataFromItem(item, type);
 
@@ -1479,7 +1481,7 @@ void CEditHandlerStatusDialog::OnEdit(wxCommandEvent& event)
 		files.push_front(item);
 	}
 
-	for (std::list<int>::const_iterator iter = files.begin(); iter != files.end(); iter++)
+	for (std::list<int>::const_iterator iter = files.begin(); iter != files.end(); ++iter)
 	{
 		const int i = *iter;
 
@@ -1559,7 +1561,7 @@ bool CNewAssociationDialog::Show(const wxString &file)
 	if (!pos)
 		m_ext = _T(".");
 	else if (pos != -1)
-		m_ext = file.Mid(pos + 1);	
+		m_ext = file.Mid(pos + 1);
 	else
 		m_ext.clear();
 
