@@ -81,7 +81,7 @@ template<class CFileData> WXLRESULT CFileListCtrl<CFileData>::MSWWindowProc(WXUI
 
 		return wxListCtrlEx::MSWWindowProc(nMsg, wParam, lParam);
 	}
-	
+
 	return wxListCtrlEx::MSWWindowProc(nMsg, wParam, lParam);
 }
 
@@ -102,7 +102,7 @@ template<class CFileData> bool CFileListCtrl<CFileData>::MSWOnNotify(int idCtrl,
 
 		if (!m_pFilelistStatusBar)
 			return true;
-		
+
 		if (wxGetKeyState(WXK_CONTROL) && wxGetKeyState(WXK_SHIFT))
 		{
 			// The behavior of Ctrl+Shift+Click is highly erratic.
@@ -210,6 +210,7 @@ class CGtkEventCallbackProxyBase
 {
 public:
 	virtual void OnNavigationEvent(bool forward) = 0;
+	virtual ~CGtkEventCallbackProxyBase() {}
 };
 
 template <class CFileData> class CGtkEventCallbackProxy : public CGtkEventCallbackProxyBase
@@ -277,6 +278,9 @@ template<class CFileData> CFileListCtrl<CFileData>::CFileListCtrl(wxWindow* pPar
 	GtkWidget* widget = GetMainWindow()->GetConnectWidget();
 	g_signal_connect(widget, "button_release_event", G_CALLBACK(gtk_button_release_event), m_gtkEventCallbackProxy.Value());
 #endif
+
+	m_genericTypes[genericTypes::file] = _("File");
+	m_genericTypes[genericTypes::directory] = _("Directory");
 }
 
 template<class CFileData> CFileListCtrl<CFileData>::~CFileListCtrl()
@@ -321,7 +325,7 @@ template<class CFileData> void CFileListCtrl<CFileData>::SortList(int column /*=
 
 #ifndef __WXMSW__
 		// GetNextItem is O(n) if nothing is selected, GetSelectedItemCount() is O(1)
-		if (GetSelectedItemCount())		
+		if (GetSelectedItemCount())
 #endif
 		{
 			int item = -1;
@@ -343,7 +347,7 @@ template<class CFileData> void CFileListCtrl<CFileData>::SortList(int column /*=
 		m_sortColumn = column;
 		std::vector<unsigned int>::iterator start = m_indexMapping.begin();
 		if (m_hasParent)
-			start++;
+			++start;
 		std::reverse(start, m_indexMapping.end());
 
 		if (updateSelections)
@@ -368,7 +372,7 @@ template<class CFileData> void CFileListCtrl<CFileData>::SortList(int column /*=
 
 	std::vector<unsigned int>::iterator start = m_indexMapping.begin();
 	if (m_hasParent)
-		start++;
+		++start;
 	CSortComparisonObject object = GetSortComparisonObject();
 	std::sort(start, m_indexMapping.end(), object);
 	object.Destroy();
@@ -460,10 +464,21 @@ template<class CFileData> void CFileListCtrl<CFileData>::OnColumnClicked(wxListE
 	RefreshListOnly(false);
 }
 
+static wxString GetExt(const wxString& file)
+{
+	wxString ret;
+
+	int pos = file.Find('.', true);
+	if (pos > 0 && file[pos + 1] != 0) // Does neither starts nor end with dot
+		ret = file.Mid(pos + 1);
+
+	return ret;
+}
+
 template<class CFileData> wxString CFileListCtrl<CFileData>::GetType(wxString name, bool dir, const wxString& path /*=_T("")*/)
 {
 #ifdef __WXMSW__
-	wxString ext = wxFileName(name).GetExt();
+	wxString ext = GetExt(name);
 	ext.MakeLower();
 	std::map<wxString, wxString>::iterator typeIter = m_fileTypeMap.find(ext);
 	if (typeIter != m_fileTypeMap.end())
@@ -471,7 +486,7 @@ template<class CFileData> wxString CFileListCtrl<CFileData>::GetType(wxString na
 
 	wxString type;
 	int flags = SHGFI_TYPENAME;
-	if (path == _T(""))
+	if (path.IsEmpty())
 		flags |= SHGFI_USEFILEATTRIBUTES;
 	else if (path == _T("\\"))
 		name += _T("\\");
@@ -486,45 +501,45 @@ template<class CFileData> wxString CFileListCtrl<CFileData>::GetType(wxString na
 		sizeof(shFinfo),
 		flags))
 	{
-		type = shFinfo.szTypeName;
-		if (type == _T(""))
+		if (!*shFinfo.szTypeName)
 		{
-			type = ext;
-			type.MakeUpper();
-			if (!type.IsEmpty())
+			if (!ext.IsEmpty())
 			{
+				type = ext;
+				type.MakeUpper();
 				type += _T("-");
 				type += _("file");
 			}
 			else
-				type = _("File");
+				type = m_genericTypes[genericTypes::file];
 		}
 		else
 		{
-			if (!dir && ext != _T(""))
+			type = shFinfo.szTypeName;
+			if (!dir && !ext.IsEmpty())
 				m_fileTypeMap[ext.MakeLower()] = type;
 		}
 	}
 	else
 	{
-		type = ext;
-		type.MakeUpper();
-		if (!type.IsEmpty())
+		if (!ext.IsEmpty())
 		{
+			type = ext;
+			type.MakeUpper();
 			type += _T("-");
 			type += _("file");
 		}
 		else
-			type = _("File");
+			type = m_genericTypes[genericTypes::file];
 	}
 	return type;
 #else
 	if (dir)
-		return _("Directory");
+		return m_genericTypes[genericTypes::directory];
 
 	int pos = name.Find('.', true);
 	if (pos < 1 || !name[pos + 1]) // Starts or ends with dot
-		return _("File");
+		return m_genericTypes[genericTypes::file];
 	wxString ext = name.Mid(pos + 1);
 	wxString lower_ext = ext.Lower();
 
