@@ -2,6 +2,7 @@
 #define __LISTCTRLEX_H__
 
 #include "systemimagelist.h"
+#include <wx/dnd.h>
 
 class wxListCtrlEx : public wxListCtrl, public CSystemImageList
 {
@@ -21,7 +22,7 @@ public:
 	void EnablePrefixSearch(bool enable) { m_prefixSearch_enabled = enable; }
 
 	// Reducing item count does not reset the focused item
- 	// if using the generic list control. Work around it.
+	// if using the generic list control. Work around it.
 	void SaveSetItemCount(long count);
 
 	void ShowColumnEditor();
@@ -31,10 +32,10 @@ public:
 	// Moves column. Target position includes both hidden
 	// as well as shown columns
 	void MoveColumn(unsigned int col, unsigned int before);
-	
+
 	// Do not call after calling LoadColumnSettings
 	void AddColumn(const wxString& name, int align, int initialWidth, bool fixed = false);
-	
+
 	// LoadColumnSettings needs to be called exactly once after adding
 	// all columns
 	void LoadColumnSettings(int widthsOptionId, int visibilityOptionId, int sortOptionId);
@@ -138,4 +139,35 @@ private:
 	wxListCtrlEx& m_listCtrl;
 };
 
+class CListCtrlDropTarget : public wxEvtHandler, public wxDropTarget
+{
+public:
+	CListCtrlDropTarget(wxListCtrlEx* pListCtrl);
+
+	virtual bool OnDrop(wxCoord x, wxCoord y);
+
+	virtual wxDragResult OnDragOver(wxCoord x, wxCoord y, wxDragResult def);
+
+	virtual void OnLeave();
+
+	virtual wxDragResult OnEnter(wxCoord x, wxCoord y, wxDragResult def);
+
+	virtual void DisplayDropHighlight(wxPoint) = 0;
+
+protected:
+	bool IsScroll(wxPoint p) const;
+	bool IsTopScroll(wxPoint p) const;
+	bool IsBottomScroll(wxPoint p) const;
+
+	void OnTimer(wxTimerEvent& /*event*/);
+
+protected:
+	wxListCtrlEx *m_pListCtrl;
+
+	wxTimer m_timer;
+	int m_count;
+
+	DECLARE_EVENT_TABLE();
+};
+
 #endif //__LISTCTRLEX_H__
