@@ -4,28 +4,29 @@
 #include "queueview_failed.h"
 #include "queueview_successful.h"
 #include "sizeformatting.h"
+#include "timeformatting.h"
 #include "themeprovider.h"
 
-CQueueItem::CQueueItem()
+CQueueItem::CQueueItem(CQueueItem* parent)
+	: m_parent(parent)
+	, m_visibleOffspring(0)
+	, m_indent(0)
+	, m_maxCachedIndex(-1)
+	, m_removed_at_front(0)
 {
-	m_visibleOffspring = 0;
-	m_parent = 0;
-	m_maxCachedIndex = -1;
-
-	m_removed_at_front = 0;
 }
 
 CQueueItem::~CQueueItem()
 {
 	std::vector<CQueueItem*>::iterator iter;
-	for (iter = m_children.begin() + m_removed_at_front; iter != m_children.end(); iter++)
+	for (iter = m_children.begin() + m_removed_at_front; iter != m_children.end(); ++iter)
 		delete *iter;
 }
 
 void CQueueItem::SetPriority(enum QueuePriority priority)
 {
 	std::vector<CQueueItem*>::iterator iter;
-	for (iter = m_children.begin() + m_removed_at_front; iter != m_children.end(); iter++)
+	for (iter = m_children.begin() + m_removed_at_front; iter != m_children.end(); ++iter)
 		(*iter)->SetPriority(priority);
 }
 
@@ -36,7 +37,7 @@ void CQueueItem::AddChild(CQueueItem* item)
 		m_children.erase(m_children.begin(), m_children.begin() + m_removed_at_front);
 		m_removed_at_front = 0;
 	}
-	item->m_indent = m_indent + _T("  ");
+	item->m_indent = m_indent + 1;
 	m_children.push_back(item);
 
 	m_visibleOffspring += 1 + item->m_visibleOffspring;
@@ -91,7 +92,7 @@ CQueueItem* CQueueItem::GetChild(unsigned int item, bool recursive /*=true*/)
 		child = m_lookupCache[m_maxCachedIndex].child + 1;
 	}
 
-	for (; iter != m_children.end(); iter++, child++)
+	for (; iter != m_children.end(); ++iter, ++child)
 	{
 		if (!item)
 			return *iter;
@@ -130,7 +131,7 @@ bool CQueueItem::RemoveChild(CQueueItem* pItem, bool destroy /*=true*/)
 	int oldVisibleOffspring = m_visibleOffspring;
 	std::vector<CQueueItem*>::iterator iter;
 	bool deleted = false;
-	for (iter = m_children.begin() + m_removed_at_front; iter != m_children.end(); iter++)
+	for (iter = m_children.begin() + m_removed_at_front; iter != m_children.end(); ++iter)
 	{
 		if (*iter == pItem)
 		{
@@ -202,7 +203,7 @@ bool CQueueItem::TryRemoveAll()
 	std::vector<CQueueItem*>::iterator iter;
 	std::vector<CQueueItem*> keepChildren;
 	m_visibleOffspring = 0;
-	for (iter = m_children.begin() + m_removed_at_front; iter != m_children.end(); iter++)
+	for (iter = m_children.begin() + m_removed_at_front; iter != m_children.end(); ++iter)
 	{
 		CQueueItem* pItem = *iter;
 		if (pItem->TryRemoveAll())
@@ -268,7 +269,7 @@ int CQueueItem::GetItemIndex() const
 		return 0;
 
 	int index = 1;
-	for (std::vector<CQueueItem*>::const_iterator iter = pParent->m_children.begin() + pParent->m_removed_at_front; iter != pParent->m_children.end(); iter++)
+	for (std::vector<CQueueItem*>::const_iterator iter = pParent->m_children.begin() + pParent->m_removed_at_front; iter != pParent->m_children.end(); ++iter)
 	{
 		if (*iter == this)
 			break;
@@ -279,26 +280,41 @@ int CQueueItem::GetItemIndex() const
 	return index + pParent->GetItemIndex();
 }
 
+const wxString& CQueueItem::GetIndent() const
+{
+	wxASSERT(m_indent < 5);
+	static const wxString indents[5] =
+	{
+		_T(""),
+		_T("  "),
+		_T("    "),
+		_T("      "),
+		_T("        ")
+	};
+	return indents[m_indent];
+}
+
 CFileItem::CFileItem(CServerItem* parent, bool queued, bool download,
-					 const CLocalPath& localPath, const wxString& localFile,
-					 const wxString& remoteFile, const CServerPath& remotePath, wxLongLong size)
-	: m_localFile(localFile), m_remoteFile(remoteFile)
-	, m_localPath(localPath), m_remotePath(remotePath)
+					 const wxString& sourceFile, const wxString& targetFile,
+					 const CLocalPath& localPath, const CServerPath& remotePath, wxLongLong size)
+	: CQueueItem(parent)
+	, m_errorCount(0)
+	, m_edit(CEditHandler::none)
+	, m_pEngineData(0)
+	, m_defaultFileExistsAction(CFileExistsNotification::unknown)
+	, m_onetime_action(CFileExistsNotification::unknown)
+	, flags(0)
+	, m_priority(priority_normal)
+	, m_sourceFile(sourceFile)
+	, m_targetFile(targetFile)
+	, m_localPath(localPath)
+	, m_remotePath(remotePath)
 	, m_size(size)
 {
-	m_parent = parent;
-	m_priority = priority_normal;
-
-	flags = 0;
 	if (download)
 		flags |= flag_download;
 	if (queued)
 		flags |= flag_queued;
-	m_errorCount = 0;
-	m_pEngineData = 0;
-	m_defaultFileExistsAction = CFileExistsNotification::unknown;
-	m_edit = CEditHandler::none;
-	m_onetime_action = CFileExistsNotification::unknown;
 }
 
 CFileItem::~CFileItem()
@@ -347,8 +363,8 @@ void CFileItem::SaveItem(TiXmlElement* pElement) const
 
 	TiXmlElement *file = pElement->LinkEndChild(new TiXmlElement("File"))->ToElement();
 
-	AddTextElement(file, "LocalFile", m_localPath.GetPath() + m_localFile);
-	AddTextElement(file, "RemoteFile", m_remoteFile);
+	AddTextElement(file, "LocalFile", m_localPath.GetPath() + GetLocalFile());
+	AddTextElement(file, "RemoteFile", GetRemoteFile());
 	AddTextElement(file, "RemotePath", m_remotePath.GetSafePath());
 	AddTextElementRaw(file, "Download", Download() ? "1" : "0");
 	if (m_size != -1)
@@ -357,7 +373,7 @@ void CFileItem::SaveItem(TiXmlElement* pElement) const
 		AddTextElement(file, "ErrorCount", m_errorCount);
 	if (m_priority != priority_normal)
 		AddTextElement(file, "Priority", m_priority);
-	AddTextElementRaw(file, "TransferMode", m_transferSettings.binary ? "1" : "0");
+	AddTextElementRaw(file, "DataType", m_transferSettings.binary ? "1" : "0");
 	if (m_defaultFileExistsAction != CFileExistsNotification::unknown)
 		AddTextElement(file, "OverwriteAction", m_defaultFileExistsAction);
 }
@@ -371,25 +387,22 @@ bool CFileItem::TryRemoveAll()
 	return false;
 }
 
-void CFileItem::SetLocalFile(const wxString &file)
+void CFileItem::SetTargetFile(const wxString &file)
 {
 	wxASSERT(!file.empty());
-	m_localFile = file;
-}
-
-void CFileItem::SetRemoteFile(const wxString &file)
-{
-	wxASSERT(!file.empty());
-	m_remoteFile = file;
+	if (file != m_sourceFile)
+		m_targetFile = file;
+	else
+		m_targetFile.clear();
 }
 
 CFolderItem::CFolderItem(CServerItem* parent, bool queued, const CLocalPath& localPath)
-	: CFileItem(parent, queued, true, localPath, _T(""), _T(""), CServerPath(), -1)
+	: CFileItem(parent, queued, true, wxEmptyString, wxEmptyString, localPath, CServerPath(), -1)
 {
 }
 
 CFolderItem::CFolderItem(CServerItem* parent, bool queued, const CServerPath& remotePath, const wxString& remoteFile)
-	: CFileItem(parent, queued, false, CLocalPath(), _T(""), remoteFile, remotePath, -1)
+	: CFileItem(parent, queued, false, _T(""), remoteFile, CLocalPath(), remotePath, -1)
 {
 }
 
@@ -398,10 +411,10 @@ void CFolderItem::SaveItem(TiXmlElement* pElement) const
 	TiXmlElement *file = new TiXmlElement("Folder");
 
 	if (Download())
-		AddTextElement(file, "LocalFile", m_localFile);
+		AddTextElement(file, "LocalFile", GetLocalPath().GetPath() + GetLocalFile());
 	else
 	{
-		AddTextElement(file, "RemoteFile", m_remoteFile);
+		AddTextElement(file, "RemoteFile", GetRemoteFile());
 		AddTextElement(file, "RemotePath", m_remotePath.GetSafePath());
 	}
 	AddTextElementRaw(file, "Download", Download() ? "1" : "0");
@@ -418,9 +431,9 @@ void CFolderItem::SetActive(const bool active)
 }
 
 CServerItem::CServerItem(const CServer& server)
+	: m_activeCount(0)
+	, m_server(server)
 {
-	m_server = server;
-	m_activeCount = 0;
 }
 
 CServerItem::~CServerItem()
@@ -456,7 +469,7 @@ void CServerItem::AddFileItemToList(CFileItem* pItem)
 void CServerItem::RemoveFileItemFromList(CFileItem* pItem)
 {
 	std::list<CFileItem*>& fileList = m_fileList[pItem->queued() ? 0 : 1][pItem->GetPriority()];
-	for (std::list<CFileItem*>::iterator iter = fileList.begin(); iter != fileList.end(); iter++)
+	for (std::list<CFileItem*>::iterator iter = fileList.begin(); iter != fileList.end(); ++iter)
 	{
 		if (*iter == pItem)
 		{
@@ -469,7 +482,7 @@ void CServerItem::RemoveFileItemFromList(CFileItem* pItem)
 
 void CServerItem::SetDefaultFileExistsAction(enum CFileExistsNotification::OverwriteAction action, const enum TransferDirection direction)
 {
-	for (std::vector<CQueueItem*>::iterator iter = m_children.begin() + m_removed_at_front; iter != m_children.end(); iter++)
+	for (std::vector<CQueueItem*>::iterator iter = m_children.begin() + m_removed_at_front; iter != m_children.end(); ++iter)
 	{
 		CQueueItem *pItem = *iter;
 		if (pItem->GetType() == QueueItemType_File)
@@ -496,7 +509,7 @@ CFileItem* CServerItem::GetIdleChild(bool immediateOnly, enum TransferDirection
 	for (i = (PRIORITY_COUNT - 1); i >= 0; i--)
 	{
 		std::list<CFileItem*>& fileList = m_fileList[1][i];
-		for (std::list<CFileItem*>::iterator iter = fileList.begin(); iter != fileList.end(); iter++)
+		for (std::list<CFileItem*>::iterator iter = fileList.begin(); iter != fileList.end(); ++iter)
 		{
 			CFileItem* item = *iter;
 			if (item->IsActive())
@@ -520,7 +533,7 @@ CFileItem* CServerItem::GetIdleChild(bool immediateOnly, enum TransferDirection
 	for (i = (PRIORITY_COUNT - 1); i >= 0; i--)
 	{
 		std::list<CFileItem*>& fileList = m_fileList[0][i];
-		for (std::list<CFileItem*>::iterator iter = fileList.begin(); iter != fileList.end(); iter++)
+		for (std::list<CFileItem*>::iterator iter = fileList.begin(); iter != fileList.end(); ++iter)
 		{
 			CFileItem* item = *iter;
 			if (item->IsActive())
@@ -562,7 +575,7 @@ void CServerItem::QueueImmediateFiles()
 	{
 		std::list<CFileItem*> activeList;
 		std::list<CFileItem*>& fileList = m_fileList[1][i];
-		for (std::list<CFileItem*>::reverse_iterator iter = fileList.rbegin(); iter != fileList.rend(); iter++)
+		for (std::list<CFileItem*>::reverse_iterator iter = fileList.rbegin(); iter != fileList.rend(); ++iter)
 		{
 			CFileItem* item = *iter;
 			wxASSERT(!item->queued());
@@ -584,7 +597,7 @@ void CServerItem::QueueImmediateFile(CFileItem* pItem)
 		return;
 
 	std::list<CFileItem*>& fileList = m_fileList[1][pItem->GetPriority()];
-	for (std::list<CFileItem*>::iterator iter = fileList.begin(); iter != fileList.end(); iter++)
+	for (std::list<CFileItem*>::iterator iter = fileList.begin(); iter != fileList.end(); ++iter)
 	{
 		if (*iter != pItem)
 			continue;
@@ -602,7 +615,7 @@ void CServerItem::SaveItem(TiXmlElement* pElement) const
 	TiXmlElement *server = new TiXmlElement("Server");
 	SetServer(server, m_server);
 
-	for (std::vector<CQueueItem*>::const_iterator iter = m_children.begin() + m_removed_at_front; iter != m_children.end(); iter++)
+	for (std::vector<CQueueItem*>::const_iterator iter = m_children.begin() + m_removed_at_front; iter != m_children.end(); ++iter)
 		(*iter)->SaveItem(server);
 
 	pElement->LinkEndChild(server);
@@ -616,7 +629,7 @@ wxLongLong CServerItem::GetTotalSize(int& filesWithUnknownSize, int& queuedFiles
 		for (int j = 0; j < 2; j++)
 		{
 			const std::list<CFileItem*>& fileList = m_fileList[j][i];
-			for (std::list<CFileItem*>::const_iterator iter = fileList.begin(); iter != fileList.end(); iter++)
+			for (std::list<CFileItem*>::const_iterator iter = fileList.begin(); iter != fileList.end(); ++iter)
 			{
 				const CFileItem* item = *iter;
 				wxLongLong size = item->GetSize();
@@ -628,7 +641,7 @@ wxLongLong CServerItem::GetTotalSize(int& filesWithUnknownSize, int& queuedFiles
 		}
 	}
 
-	for (std::vector<CQueueItem*>::const_iterator iter = m_children.begin() + m_removed_at_front; iter != m_children.end(); iter++)
+	for (std::vector<CQueueItem*>::const_iterator iter = m_children.begin() + m_removed_at_front; iter != m_children.end(); ++iter)
 	{
 		if ((*iter)->GetType() == QueueItemType_File ||
 			(*iter)->GetType() == QueueItemType_Folder)
@@ -646,7 +659,7 @@ bool CServerItem::TryRemoveAll()
 	std::vector<CQueueItem*>::iterator iter;
 	std::vector<CQueueItem*> keepChildren;
 	m_visibleOffspring = 0;
-	for (iter = m_children.begin() + m_removed_at_front; iter != m_children.end(); iter++)
+	for (iter = m_children.begin() + m_removed_at_front; iter != m_children.end(); ++iter)
 	{
 		CQueueItem* pItem = *iter;
 		if (pItem->TryRemoveAll())
@@ -695,7 +708,7 @@ void CServerItem::DetachChildren()
 void CServerItem::SetPriority(enum QueuePriority priority)
 {
 	std::vector<CQueueItem*>::iterator iter;
-	for (iter = m_children.begin() + m_removed_at_front; iter != m_children.end(); iter++)
+	for (iter = m_children.begin() + m_removed_at_front; iter != m_children.end(); ++iter)
 	{
 		if ((*iter)->GetType() == QueueItemType_File)
 			((CFileItem*)(*iter))->SetPriorityRaw(priority);
@@ -713,7 +726,7 @@ void CServerItem::SetChildPriority(CFileItem* pItem, enum QueuePriority oldPrior
 {
 	int i = pItem->queued() ? 0 : 1;
 
-	for (std::list<CFileItem*>::iterator iter = m_fileList[i][oldPriority].begin(); iter != m_fileList[i][oldPriority].end(); iter++)
+	for (std::list<CFileItem*>::iterator iter = m_fileList[i][oldPriority].begin(); iter != m_fileList[i][oldPriority].end(); ++iter)
 	{
 		if (*iter != pItem)
 			continue;
@@ -727,19 +740,17 @@ void CServerItem::SetChildPriority(CFileItem* pItem, enum QueuePriority oldPrior
 }
 
 CFolderScanItem::CFolderScanItem(CServerItem* parent, bool queued, bool download, const CLocalPath& localPath, const CServerPath& remotePath)
+	: CQueueItem(parent)
+	, m_remove(false)
+	, m_active(false)
+	, m_count(0)
+	, m_defaultFileExistsAction(CFileExistsNotification::unknown)
+	, m_dir_is_empty(false)
+	, m_queued(queued)
+	, m_localPath(localPath)
+	, m_remotePath(remotePath)
+	, m_download(download)
 {
-	m_parent = parent;
-
-	m_download = download;
-	m_localPath = localPath;
-	m_remotePath = remotePath;
-	m_queued = queued;
-	m_remove = false;
-	m_active = false;
-	m_count = 0;
-	m_dir_is_empty = false;
-
-	m_defaultFileExistsAction = CFileExistsNotification::unknown;
 }
 
 bool CFolderScanItem::TryRemoveAll()
@@ -765,8 +776,9 @@ EVT_KEY_DOWN(CQueueViewBase::OnKeyDown)
 END_EVENT_TABLE()
 
 CQueueViewBase::CQueueViewBase(CQueue* parent, int index, const wxString& title)
-	: wxListCtrlEx(parent, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxCLIP_CHILDREN | wxLC_REPORT | wxLC_VIRTUAL | wxSUNKEN_BORDER | wxTAB_TRAVERSAL),
-	  m_pageIndex(index), m_title(title)
+	: wxListCtrlEx(parent, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxCLIP_CHILDREN | wxLC_REPORT | wxLC_VIRTUAL | wxSUNKEN_BORDER | wxTAB_TRAVERSAL)
+	, m_pageIndex(index)
+	, m_title(title)
 {
 	m_pQueue = parent;
 	m_insertionStart = -1;
@@ -795,14 +807,14 @@ CQueueViewBase::CQueueViewBase(CQueue* parent, int index, const wxString& title)
 
 CQueueViewBase::~CQueueViewBase()
 {
-	for (std::vector<CServerItem*>::iterator iter = m_serverList.begin(); iter != m_serverList.end(); iter++)
+	for (std::vector<CServerItem*>::iterator iter = m_serverList.begin(); iter != m_serverList.end(); ++iter)
 		delete *iter;
 }
 
 CQueueItem* CQueueViewBase::GetQueueItem(unsigned int item)
 {
 	std::vector<CServerItem*>::iterator iter;
-	for (iter = m_serverList.begin(); iter != m_serverList.end(); iter++)
+	for (iter = m_serverList.begin(); iter != m_serverList.end(); ++iter)
 	{
 		if (!item)
 			return *iter;
@@ -824,7 +836,7 @@ int CQueueViewBase::GetItemIndex(const CQueueItem* item)
 	const CQueueItem* pTopLevelItem = item->GetTopLevelItem();
 
 	int index = 0;
-	for (std::vector<CServerItem*>::const_iterator iter = m_serverList.begin(); iter != m_serverList.end(); iter++)
+	for (std::vector<CServerItem*>::const_iterator iter = m_serverList.begin(); iter != m_serverList.end(); ++iter)
 	{
 		if (pTopLevelItem == *iter)
 			break;
@@ -843,12 +855,20 @@ void CQueueViewBase::OnEraseBackground(wxEraseEvent& event)
 
 wxString CQueueViewBase::OnGetItemText(long item, long column) const
 {
+	if (column < 0 || static_cast<std::size_t>(column) >= m_columns.size())
+		return _T("");
+
 	CQueueViewBase* pThis = const_cast<CQueueViewBase*>(this);
 
 	CQueueItem* pItem = pThis->GetQueueItem(item);
 	if (!pItem)
 		return _T("");
 
+	return OnGetItemText(pItem, m_columns[column]);
+}
+
+wxString CQueueViewBase::OnGetItemText(CQueueItem* pItem, ColumnId column) const
+{
 	switch (pItem->GetType())
 	{
 	case QueueItemType_Server:
@@ -863,9 +883,9 @@ wxString CQueueViewBase::OnGetItemText(long item, long column) const
 			CFileItem* pFileItem = reinterpret_cast<CFileItem*>(pItem);
 			switch (column)
 			{
-			case 0:
+			case colLocalName:
 				return pFileItem->GetIndent() + pFileItem->GetLocalPath().GetPath() + pFileItem->GetLocalFile();
-			case 1:
+			case colDirection:
 				if (pFileItem->Download())
 					if (pFileItem->queued())
 						return _T("<--");
@@ -877,9 +897,9 @@ wxString CQueueViewBase::OnGetItemText(long item, long column) const
 					else
 						return _T("-->>");
 				break;
-			case 2:
+			case colRemoteName:
 				return pFileItem->GetRemotePath().FormatFilename(pFileItem->GetRemoteFile());
-			case 3:
+			case colSize:
 				{
 					const wxLongLong& size = pFileItem->GetSize();
 					if (size >= 0)
@@ -887,7 +907,7 @@ wxString CQueueViewBase::OnGetItemText(long item, long column) const
 					else
 						return _T("?");
 				}
-			case 4:
+			case colPriority:
 				switch (pFileItem->GetPriority())
 				{
 				case 0:
@@ -903,8 +923,11 @@ wxString CQueueViewBase::OnGetItemText(long item, long column) const
 					return _("Highest");
 				}
 				break;
-			case 5:
+			case colTransferStatus:
+			case colErrorReason:
 				return pFileItem->m_statusMessage;
+			case colTime:
+				return CTimeFormat::FormatDateTime(pItem->GetTime());
 			default:
 				break;
 			}
@@ -915,9 +938,9 @@ wxString CQueueViewBase::OnGetItemText(long item, long column) const
 			CFolderScanItem* pFolderItem = reinterpret_cast<CFolderScanItem*>(pItem);
 			switch (column)
 			{
-			case 0:
+			case colLocalName:
 				return _T("  ") + pFolderItem->GetLocalPath().GetPath();
-			case 1:
+			case colDirection:
 				if (pFolderItem->Download())
 					if (pFolderItem->queued())
 						return _T("<--");
@@ -929,10 +952,13 @@ wxString CQueueViewBase::OnGetItemText(long item, long column) const
 					else
 						return _T("-->>");
 				break;
-			case 2:
+			case colRemoteName:
 				return pFolderItem->GetRemotePath().GetPath();
-			case 5:
+			case colTransferStatus:
+			case colErrorReason:
 				return pFolderItem->m_statusMessage;
+			case colTime:
+				return CTimeFormat::FormatDateTime(pItem->GetTime());
 			default:
 				break;
 			}
@@ -943,11 +969,11 @@ wxString CQueueViewBase::OnGetItemText(long item, long column) const
 			CFileItem* pFolderItem = reinterpret_cast<CFolderItem*>(pItem);
 			switch (column)
 			{
-			case 0:
+			case colLocalName:
 				if (pFolderItem->Download())
 					return pFolderItem->GetIndent() + pFolderItem->GetLocalPath().GetPath() + pFolderItem->GetLocalFile();
 				break;
-			case 1:
+			case colDirection:
 				if (pFolderItem->Download())
 					if (pFolderItem->queued())
 						return _T("<--");
@@ -959,7 +985,7 @@ wxString CQueueViewBase::OnGetItemText(long item, long column) const
 					else
 						return _T("-->>");
 				break;
-			case 2:
+			case colRemoteName:
 				if (!pFolderItem->Download())
 				{
 					if (pFolderItem->GetRemoteFile() == _T(""))
@@ -968,7 +994,7 @@ wxString CQueueViewBase::OnGetItemText(long item, long column) const
 						return pFolderItem->GetRemotePath().FormatFilename(pFolderItem->GetRemoteFile());
 				}
 				break;
-			case 4:
+			case colPriority:
 				switch (pFolderItem->GetPriority())
 				{
 				case 0:
@@ -984,8 +1010,11 @@ wxString CQueueViewBase::OnGetItemText(long item, long column) const
 					return _("Highest");
 				}
 				break;
-			case 5:
+			case colTransferStatus:
+			case colErrorReason:
 				return pFolderItem->m_statusMessage;
+			case colTime:
+				return CTimeFormat::FormatDateTime(pItem->GetTime());
 			default:
 				break;
 			}
@@ -1101,7 +1130,7 @@ void CQueueViewBase::UpdateSelections_ItemRangeAdded(int added, int count)
 
 		item = GetNextItem(item, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
 	}
-	for (std::list<int>::const_iterator iter = itemsToSelect.begin(); iter != itemsToSelect.end(); iter++)
+	for (std::list<int>::const_iterator iter = itemsToSelect.begin(); iter != itemsToSelect.end(); ++iter)
 		SetItemState(*iter, wxLIST_STATE_SELECTED, wxLIST_STATE_SELECTED);
 }
 
@@ -1182,28 +1211,37 @@ void CQueueViewBase::UpdateSelections_ItemRangeRemoved(int removed, int count)
 
 		item = GetNextItem(item, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
 	}
-	for (std::list<int>::const_iterator iter = itemsToUnselect.begin(); iter != itemsToUnselect.end(); iter++)
+	for (std::list<int>::const_iterator iter = itemsToUnselect.begin(); iter != itemsToUnselect.end(); ++iter)
 		SetItemState(*iter, 0, wxLIST_STATE_SELECTED);
 }
 
-void CQueueViewBase::CreateColumns(const wxString& lastColumnName)
+void CQueueViewBase::AddQueueColumn(ColumnId id)
 {
-	const unsigned long widths[6] = { 180, 60, 180, 80, 60, 150 };
+	const unsigned long widths[8] = { 180, 60, 180, 80, 60, 100, 150, 150 };
+	const int alignment[8] = { wxLIST_FORMAT_LEFT, wxLIST_FORMAT_CENTER, wxLIST_FORMAT_LEFT, wxLIST_FORMAT_RIGHT, wxLIST_FORMAT_LEFT, wxLIST_FORMAT_LEFT, wxLIST_FORMAT_LEFT, wxLIST_FORMAT_LEFT };
+	const wxString names[8] = { _("Server/Local file"), _("Direction"), _("Remote file"), _("Size"), _("Priority"), _("Time"), _("Status"), _("Reason") };
 
-	AddColumn(_("Server/Local file"), wxLIST_FORMAT_LEFT, widths[0]);
-	AddColumn(_("Direction"), wxLIST_FORMAT_CENTER, widths[1]);
-	AddColumn(_("Remote file"), wxLIST_FORMAT_LEFT, widths[2]);
-	AddColumn(_("Size"), wxLIST_FORMAT_RIGHT, widths[3]);
-	AddColumn(_("Priority"), wxLIST_FORMAT_LEFT, widths[4]);
-	if (lastColumnName != _T(""))
-		AddColumn(lastColumnName, wxLIST_FORMAT_LEFT, widths[5]);
+	AddColumn(names[id], alignment[id], widths[id]);
+	m_columns.push_back(id);
+}
+
+void CQueueViewBase::CreateColumns(std::list<ColumnId> const& extraColumns)
+{
+	AddQueueColumn(colLocalName);
+	AddQueueColumn(colDirection);
+	AddQueueColumn(colRemoteName);
+	AddQueueColumn(colSize);
+	AddQueueColumn(colPriority);
+
+	for( std::list<ColumnId>::const_iterator it = extraColumns.begin(); it != extraColumns.end(); ++it)
+		AddQueueColumn(*it);
 
 	LoadColumnSettings(OPTION_QUEUE_COLUMN_WIDTHS, -1, -1);
 }
 
 CServerItem* CQueueViewBase::GetServerItem(const CServer& server)
 {
-	for (std::vector<CServerItem*>::iterator iter = m_serverList.begin(); iter != m_serverList.end(); iter++)
+	for (std::vector<CServerItem*>::iterator iter = m_serverList.begin(); iter != m_serverList.end(); ++iter)
 	{
 		if ((*iter)->GetServer() == server)
 			return *iter;
@@ -1336,7 +1374,7 @@ bool CQueueViewBase::RemoveItem(CQueueItem* pItem, bool destroy, bool updateItem
 	if (!topLevelItem->GetChild(0))
 	{
 		std::vector<CServerItem*>::iterator iter;
-		for (iter = m_serverList.begin(); iter != m_serverList.end(); iter++)
+		for (iter = m_serverList.begin(); iter != m_serverList.end(); ++iter)
 		{
 			if (*iter == topLevelItem)
 				break;
