@@ -6,6 +6,7 @@
 #include "Options.h"
 #include "loginmanager.h"
 #include "Mainfrm.h"
+#include "asksavepassworddialog.h"
 
 BEGIN_EVENT_TABLE(CQuickconnectBar, wxPanel)
 EVT_BUTTON(XRCID("ID_QUICKCONNECT_OK"), CQuickconnectBar::OnQuickconnect)
@@ -31,7 +32,7 @@ CQuickconnectBar::~CQuickconnectBar()
 bool CQuickconnectBar::Create(CMainFrame* pParent)
 {
 	m_pMainFrame = pParent;
-    if (!wxXmlResource::Get()->LoadPanel(this, pParent, _T("ID_QUICKCONNECTBAR")))
+	if (!wxXmlResource::Get()->LoadPanel(this, pParent, _T("ID_QUICKCONNECTBAR")))
 	{
 		wxLogError(_("Cannot load Quickconnect bar from resource file"));
 		return false;
@@ -73,7 +74,7 @@ void CQuickconnectBar::OnQuickconnect(wxCommandEvent& event)
 	wxString user = m_pUser->GetValue();
 	wxString pass = m_pPass->GetValue();
 	wxString port = m_pPort->GetValue();
-	
+
 	CServer server;
 
 	wxString error;
@@ -106,7 +107,7 @@ void CQuickconnectBar::OnQuickconnect(wxCommandEvent& event)
 		}
 		break;
 	}
-	
+
 	m_pHost->SetValue(host);
 	if (server.GetPort() != server.GetDefaultPort(server.GetProtocol()))
 		m_pPort->SetValue(wxString::Format(_T("%d"), server.GetPort()));
@@ -129,6 +130,9 @@ void CQuickconnectBar::OnQuickconnect(wxCommandEvent& event)
 	if (event.GetId() == 1)
 		server.SetBypassProxy(true);
 
+	if (server.GetLogonType() != ANONYMOUS && !CAskSavePasswordDialog::Run(this))
+		return;
+
 	if (!m_pMainFrame->ConnectToServer(server, path))
 		return;
 
@@ -153,7 +157,7 @@ void CQuickconnectBar::OnQuickconnectDropdown(wxCommandEvent& event)
 		unsigned int i = 0;
 		for (std::list<CServer>::const_iterator iter = m_recentServers.begin();
 			iter != m_recentServers.end();
-			iter++, i++)
+			++iter, ++i)
 		{
 			wxString name(iter->FormatServer());
 			name.Replace(_T("&"), _T("&&"));
