@@ -45,7 +45,7 @@ CStatusLineCtrl::CStatusLineCtrl(CQueueView* pParent, const t_EngineData* const
 	m_pParent = pParent;
 	m_pStatus = 0;
 	m_lastOffset = -1;
-	
+
 	m_gcLastTimeStamp = wxDateTime::Now();
 	m_gcLastOffset = -1;
 	m_gcLastSpeed = -1;
@@ -99,10 +99,12 @@ void CStatusLineCtrl::OnPaint(wxPaintEvent& event)
 		delete m_mdc;
 		m_data = wxBitmap(rect.GetWidth(), rect.GetHeight());
 		m_mdc = new wxMemoryDC(m_data);
+		// Use same layout direction as the DC which bitmap is drawn on. 
+		// This avoids problem with mirrored characters on RTL locales. 
+		m_mdc->SetLayoutDirection(dc.GetLayoutDirection()); 
 		refresh = 31;
 	}
 
-	int elapsed_seconds = 0;
 	wxTimeSpan elapsed;
 	int left = -1;
 	wxFileOffset rate;
@@ -136,6 +138,7 @@ void CStatusLineCtrl::OnPaint(wxPaintEvent& event)
 			refresh = 31;
 		}
 
+		int elapsed_seconds = 0;
 		if (m_pStatus->started.IsValid())
 		{
 			elapsed = wxDateTime::Now().Subtract(m_pStatus->started);
@@ -151,11 +154,15 @@ void CStatusLineCtrl::OnPaint(wxPaintEvent& event)
 		if (COptions::Get()->GetOptionVal(OPTION_SPEED_DISPLAY))
 			rate = GetCurrentSpeed();
 		else
-		    rate = GetSpeed(elapsed_seconds);
+			rate = GetSpeed(elapsed_seconds);
 
-		if (elapsed_seconds && rate > 0)
+		if (m_pStatus->totalSize > 0 && elapsed_seconds && rate > 0)
 		{
-			left = ((m_pStatus->totalSize - m_pStatus->startOffset) / rate) - elapsed_seconds;
+			wxFileOffset r = m_pStatus->totalSize - m_pStatus->currentOffset;
+			left = r / rate + 1;
+			if (r)
+				++left;
+
 			if (left < 0)
 				left = 0;
 		}
@@ -169,12 +176,14 @@ void CStatusLineCtrl::OnPaint(wxPaintEvent& event)
 		const wxString bytestr = CSizeFormat::Format(m_pStatus->currentOffset, true, CSizeFormat::bytes, COptions::Get()->GetOptionVal(OPTION_SIZE_USETHOUSANDSEP) != 0, 0);
 		if (elapsed_seconds && rate > -1)
 		{
-			if (rate > (1000*1000))
-				bytes_and_rate.Printf(_("%s (%d.%d MB/s)"), bytestr.c_str(), (int)(rate / 1000 / 1000), (int)((rate / 1000 / 100) % 10));
-			else if (rate > 1000)
-				bytes_and_rate.Printf(_("%s (%d.%d KB/s)"), bytestr.c_str(), (int)(rate / 1000), (int)((rate / 100) % 10));
-			else
-				bytes_and_rate.Printf(_("%s (%d B/s)"), bytestr.c_str(), (int)rate);
+			CSizeFormat::_format format = static_cast<CSizeFormat::_format>(COptions::Get()->GetOptionVal(OPTION_SIZE_FORMAT));
+			if (format == CSizeFormat::bytes)
+				format = CSizeFormat::iec;
+			const wxString ratestr = CSizeFormat::Format(rate, true,
+														 format,
+														 COptions::Get()->GetOptionVal(OPTION_SIZE_USETHOUSANDSEP) != 0,
+														 COptions::Get()->GetOptionVal(OPTION_SIZE_DECIMALPLACES));
+			bytes_and_rate.Printf(_("%s (%s/s)"), bytestr.c_str(), ratestr.c_str() );
 		}
 		else
 			bytes_and_rate.Printf(_("%s (? B/s)"), bytestr.c_str());
@@ -211,7 +220,7 @@ void CStatusLineCtrl::OnPaint(wxPaintEvent& event)
 		m_mdc->SetPen(GetBackgroundColour());
 		m_mdc->SetBrush(GetBackgroundColour());
 		m_mdc->SetTextForeground(GetForegroundColour());
-	
+
 		// Get character height so that we can center the text vertically.
 		wxCoord h = (rect.GetHeight() - m_textHeight) / 2;
 
@@ -314,7 +323,7 @@ void CStatusLineCtrl::OnTimer(wxTimerEvent& event)
 			m_pEngineData->pItem->GetType() == QueueItemType_File)
 		{
 			CFileItem* pItem = (CFileItem*)m_pEngineData->pItem;
-			pItem->m_madeProgress = true;
+			pItem->set_made_progress(true);
 		}
 		SetTransferStatus(&status);
 	}
@@ -374,7 +383,7 @@ void CStatusLineCtrl::DrawProgressBar(wxDC& dc, int x, int y, int height, int ba
 		prefix = _T("> ");
 		permill = 1000;
 	}
-	
+
 	wxString text = wxString::Format(_T("%s%d.%d%%"), prefix.c_str(), permill / 10, permill % 10);
 
 	wxCoord w, h;
@@ -418,21 +427,21 @@ wxFileOffset CStatusLineCtrl::GetCurrentSpeed()
 {
 	if (!m_pStatus)
 		return -1;
-	
+
 	const wxTimeSpan timeDiff( wxDateTime::UNow().Subtract(m_gcLastTimeStamp) );
-	
+
 	if (timeDiff.GetMilliseconds().GetLo() <= 2000)
 		return m_gcLastSpeed;
 
 	m_gcLastTimeStamp = wxDateTime::UNow();
 
 	if (m_gcLastOffset == -1)
-	    m_gcLastOffset = m_pStatus->startOffset;
-	
+		m_gcLastOffset = m_pStatus->startOffset;
+
 	const wxFileOffset fileOffsetDiff = m_pStatus->currentOffset - m_gcLastOffset;
 	m_gcLastOffset = m_pStatus->currentOffset;
 	m_gcLastSpeed = fileOffsetDiff * 1000 / timeDiff.GetMilliseconds().GetLo();
-	
+
 	return m_gcLastSpeed;
 }
 
